"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2
import bilireq.grpc.protos.bilibili.pagination.pagination_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _CategorySort:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CategorySortEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CategorySort.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CATEGORY_SORT_DEFAULT: _CategorySort.ValueType  # 0
    """"""
    CATEGORY_SORT_PUBLISH_TIME: _CategorySort.ValueType  # 1
    """"""
    CATEGORY_SORT_CLICK_COUNT: _CategorySort.ValueType  # 2
    """"""
    CATEGORY_SORT_COMMENT_COUNT: _CategorySort.ValueType  # 3
    """"""
    CATEGORY_SORT_LIKE_COUNT: _CategorySort.ValueType  # 4
    """"""

class CategorySort(_CategorySort, metaclass=_CategorySortEnumTypeWrapper):
    """"""

CATEGORY_SORT_DEFAULT: CategorySort.ValueType  # 0
""""""
CATEGORY_SORT_PUBLISH_TIME: CategorySort.ValueType  # 1
""""""
CATEGORY_SORT_CLICK_COUNT: CategorySort.ValueType  # 2
""""""
CATEGORY_SORT_COMMENT_COUNT: CategorySort.ValueType  # 3
""""""
CATEGORY_SORT_LIKE_COUNT: CategorySort.ValueType  # 4
""""""
global___CategorySort = CategorySort

class _Sort:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SortEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Sort.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SORT_DEFAULT: _Sort.ValueType  # 0
    """"""
    SORT_VIEW_COUNT: _Sort.ValueType  # 1
    """"""
    SORT_PUBLISH_TIME: _Sort.ValueType  # 2
    """"""
    SORT_DANMAKU_COUNT: _Sort.ValueType  # 3
    """"""

class Sort(_Sort, metaclass=_SortEnumTypeWrapper):
    """"""

SORT_DEFAULT: Sort.ValueType  # 0
""""""
SORT_VIEW_COUNT: Sort.ValueType  # 1
""""""
SORT_PUBLISH_TIME: Sort.ValueType  # 2
""""""
SORT_DANMAKU_COUNT: Sort.ValueType  # 3
""""""
global___Sort = Sort

class _UserSort:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _UserSortEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_UserSort.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    USER_SORT_DEFAULT: _UserSort.ValueType  # 0
    """"""
    USER_SORT_FANS_DESCEND: _UserSort.ValueType  # 1
    """"""
    USER_SORT_FANS_ASCEND: _UserSort.ValueType  # 2
    """"""
    USER_SORT_LEVEL_DESCEND: _UserSort.ValueType  # 3
    """"""
    USER_SORT_LEVEL_ASCEND: _UserSort.ValueType  # 4
    """"""

class UserSort(_UserSort, metaclass=_UserSortEnumTypeWrapper):
    """"""

USER_SORT_DEFAULT: UserSort.ValueType  # 0
""""""
USER_SORT_FANS_DESCEND: UserSort.ValueType  # 1
""""""
USER_SORT_FANS_ASCEND: UserSort.ValueType  # 2
""""""
USER_SORT_LEVEL_DESCEND: UserSort.ValueType  # 3
""""""
USER_SORT_LEVEL_ASCEND: UserSort.ValueType  # 4
""""""
global___UserSort = UserSort

class _UserType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _UserTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_UserType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ALL: _UserType.ValueType  # 0
    """"""
    UP: _UserType.ValueType  # 1
    """"""
    NORMAL_USER: _UserType.ValueType  # 2
    """"""
    AUTHENTICATED_USER: _UserType.ValueType  # 3
    """"""

class UserType(_UserType, metaclass=_UserTypeEnumTypeWrapper):
    """"""

ALL: UserType.ValueType  # 0
""""""
UP: UserType.ValueType  # 1
""""""
NORMAL_USER: UserType.ValueType  # 2
""""""
AUTHENTICATED_USER: UserType.ValueType  # 3
""""""
global___UserType = UserType

@typing_extensions.final
class Args(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ONLINE_FIELD_NUMBER: builtins.int
    RNAME_FIELD_NUMBER: builtins.int
    ROOM_ID_FIELD_NUMBER: builtins.int
    TNAME_FIELD_NUMBER: builtins.int
    UP_ID_FIELD_NUMBER: builtins.int
    UP_NAME_FIELD_NUMBER: builtins.int
    RID_FIELD_NUMBER: builtins.int
    TID_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    online: builtins.int
    """"""
    rname: builtins.str
    """"""
    room_id: builtins.int
    """"""
    tname: builtins.str
    """"""
    up_id: builtins.int
    """"""
    up_name: builtins.str
    """"""
    rid: builtins.int
    """"""
    tid: builtins.int
    """"""
    aid: builtins.int
    """"""
    def __init__(
        self,
        *,
        online: builtins.int = ...,
        rname: builtins.str = ...,
        room_id: builtins.int = ...,
        tname: builtins.str = ...,
        up_id: builtins.int = ...,
        up_name: builtins.str = ...,
        rid: builtins.int = ...,
        tid: builtins.int = ...,
        aid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "online", b"online", "rid", b"rid", "rname", b"rname", "room_id", b"room_id", "tid", b"tid", "tname", b"tname", "up_id", b"up_id", "up_name", b"up_name"]) -> None: ...

global___Args = Args

@typing_extensions.final
class Avatar(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COVER_FIELD_NUMBER: builtins.int
    EVENT_FIELD_NUMBER: builtins.int
    EVENT_V2_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    UP_ID_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    FACE_NFT_NEW_FIELD_NUMBER: builtins.int
    NFT_FACE_ICON_FIELD_NUMBER: builtins.int
    cover: builtins.str
    """"""
    event: builtins.str
    """"""
    event_v2: builtins.str
    """"""
    text: builtins.str
    """"""
    up_id: builtins.int
    """"""
    uri: builtins.str
    """"""
    face_nft_new: builtins.int
    """"""
    @property
    def nft_face_icon(self) -> global___NftFaceIcon:
        """"""
    def __init__(
        self,
        *,
        cover: builtins.str = ...,
        event: builtins.str = ...,
        event_v2: builtins.str = ...,
        text: builtins.str = ...,
        up_id: builtins.int = ...,
        uri: builtins.str = ...,
        face_nft_new: builtins.int = ...,
        nft_face_icon: global___NftFaceIcon | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["nft_face_icon", b"nft_face_icon"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "event", b"event", "event_v2", b"event_v2", "face_nft_new", b"face_nft_new", "nft_face_icon", b"nft_face_icon", "text", b"text", "up_id", b"up_id", "uri", b"uri"]) -> None: ...

global___Avatar = Avatar

@typing_extensions.final
class AvItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    CTIME_LABEL_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    PLAY_FIELD_NUMBER: builtins.int
    DANMAKU_FIELD_NUMBER: builtins.int
    CTIME_FIELD_NUMBER: builtins.int
    GOTO_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    POSITION_FIELD_NUMBER: builtins.int
    CTIME_LABEL_V2_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    uri: builtins.str
    """"""
    ctime_label: builtins.str
    """"""
    duration: builtins.str
    """"""
    play: builtins.int
    """"""
    danmaku: builtins.int
    """"""
    ctime: builtins.int
    """"""
    goto: builtins.str
    """"""
    param: builtins.str
    """"""
    position: builtins.int
    """"""
    ctime_label_v2: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        uri: builtins.str = ...,
        ctime_label: builtins.str = ...,
        duration: builtins.str = ...,
        play: builtins.int = ...,
        danmaku: builtins.int = ...,
        ctime: builtins.int = ...,
        goto: builtins.str = ...,
        param: builtins.str = ...,
        position: builtins.int = ...,
        ctime_label_v2: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "ctime", b"ctime", "ctime_label", b"ctime_label", "ctime_label_v2", b"ctime_label_v2", "danmaku", b"danmaku", "duration", b"duration", "goto", b"goto", "param", b"param", "play", b"play", "position", b"position", "title", b"title", "uri", b"uri"]) -> None: ...

global___AvItem = AvItem

@typing_extensions.final
class Background(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHOW_FIELD_NUMBER: builtins.int
    BG_PIC_URL_FIELD_NUMBER: builtins.int
    FG_PIC_URL_FIELD_NUMBER: builtins.int
    show: builtins.int
    """"""
    bg_pic_url: builtins.str
    """"""
    fg_pic_url: builtins.str
    """"""
    def __init__(
        self,
        *,
        show: builtins.int = ...,
        bg_pic_url: builtins.str = ...,
        fg_pic_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_pic_url", b"bg_pic_url", "fg_pic_url", b"fg_pic_url", "show", b"show"]) -> None: ...

global___Background = Background

@typing_extensions.final
class Badge(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    BG_COVER_FIELD_NUMBER: builtins.int
    text: builtins.str
    """"""
    bg_cover: builtins.str
    """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        bg_cover: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_cover", b"bg_cover", "text", b"text"]) -> None: ...

global___Badge = Badge

@typing_extensions.final
class Badge2(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BG_COVER_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    bg_cover: builtins.str
    """"""
    text: builtins.str
    """"""
    def __init__(
        self,
        *,
        bg_cover: builtins.str = ...,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_cover", b"bg_cover", "text", b"text"]) -> None: ...

global___Badge2 = Badge2

@typing_extensions.final
class BottomButton(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESC_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    desc: builtins.str
    """"""
    link: builtins.str
    """"""
    def __init__(
        self,
        *,
        desc: builtins.str = ...,
        link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc", b"desc", "link", b"link"]) -> None: ...

global___BottomButton = BottomButton

@typing_extensions.final
class BrandADAccount(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAM_FIELD_NUMBER: builtins.int
    GOTO_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    SIGN_FIELD_NUMBER: builtins.int
    RELATION_FIELD_NUMBER: builtins.int
    ROOMID_FIELD_NUMBER: builtins.int
    LIVE_STATUS_FIELD_NUMBER: builtins.int
    LIVE_LINK_FIELD_NUMBER: builtins.int
    OFFICIAL_VERIFY_FIELD_NUMBER: builtins.int
    VIP_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    FACE_NFT_NEW_FIELD_NUMBER: builtins.int
    param: builtins.str
    """"""
    goto: builtins.str
    """"""
    mid: builtins.int
    """"""
    name: builtins.str
    """"""
    face: builtins.str
    """"""
    sign: builtins.str
    """"""
    @property
    def relation(self) -> global___Relation:
        """"""
    roomid: builtins.int
    """"""
    live_status: builtins.int
    """"""
    live_link: builtins.str
    """"""
    @property
    def official_verify(self) -> global___OfficialVerify:
        """"""
    @property
    def vip(self) -> global___VipInfo:
        """"""
    uri: builtins.str
    """"""
    face_nft_new: builtins.int
    """"""
    def __init__(
        self,
        *,
        param: builtins.str = ...,
        goto: builtins.str = ...,
        mid: builtins.int = ...,
        name: builtins.str = ...,
        face: builtins.str = ...,
        sign: builtins.str = ...,
        relation: global___Relation | None = ...,
        roomid: builtins.int = ...,
        live_status: builtins.int = ...,
        live_link: builtins.str = ...,
        official_verify: global___OfficialVerify | None = ...,
        vip: global___VipInfo | None = ...,
        uri: builtins.str = ...,
        face_nft_new: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["official_verify", b"official_verify", "relation", b"relation", "vip", b"vip"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["face", b"face", "face_nft_new", b"face_nft_new", "goto", b"goto", "live_link", b"live_link", "live_status", b"live_status", "mid", b"mid", "name", b"name", "official_verify", b"official_verify", "param", b"param", "relation", b"relation", "roomid", b"roomid", "sign", b"sign", "uri", b"uri", "vip", b"vip"]) -> None: ...

global___BrandADAccount = BrandADAccount

@typing_extensions.final
class BrandADArc(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAM_FIELD_NUMBER: builtins.int
    GOTO_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    PLAY_FIELD_NUMBER: builtins.int
    REPLY_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    param: builtins.str
    """"""
    goto: builtins.str
    """"""
    aid: builtins.int
    """"""
    play: builtins.int
    """"""
    reply: builtins.int
    """"""
    duration: builtins.str
    """"""
    author: builtins.str
    """"""
    title: builtins.str
    """"""
    uri: builtins.str
    """"""
    cover: builtins.str
    """"""
    def __init__(
        self,
        *,
        param: builtins.str = ...,
        goto: builtins.str = ...,
        aid: builtins.int = ...,
        play: builtins.int = ...,
        reply: builtins.int = ...,
        duration: builtins.str = ...,
        author: builtins.str = ...,
        title: builtins.str = ...,
        uri: builtins.str = ...,
        cover: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "author", b"author", "cover", b"cover", "duration", b"duration", "goto", b"goto", "param", b"param", "play", b"play", "reply", b"reply", "title", b"title", "uri", b"uri"]) -> None: ...

global___BrandADArc = BrandADArc

@typing_extensions.final
class Button(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    EVENT_FIELD_NUMBER: builtins.int
    SELECTED_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    EVENT_V2_FIELD_NUMBER: builtins.int
    RELATION_FIELD_NUMBER: builtins.int
    text: builtins.str
    """"""
    param: builtins.str
    """"""
    uri: builtins.str
    """"""
    event: builtins.str
    """"""
    selected: builtins.int
    """"""
    type: builtins.int
    """"""
    event_v2: builtins.str
    """"""
    @property
    def relation(self) -> global___Relation:
        """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        param: builtins.str = ...,
        uri: builtins.str = ...,
        event: builtins.str = ...,
        selected: builtins.int = ...,
        type: builtins.int = ...,
        event_v2: builtins.str = ...,
        relation: global___Relation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["relation", b"relation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["event", b"event", "event_v2", b"event_v2", "param", b"param", "relation", b"relation", "selected", b"selected", "text", b"text", "type", b"type", "uri", b"uri"]) -> None: ...

global___Button = Button

@typing_extensions.final
class ButtonMeta(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    BUTTON_STATUS_FIELD_NUMBER: builtins.int
    TOAST_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """"""
    text: builtins.str
    """"""
    button_status: builtins.str
    """"""
    toast: builtins.str
    """"""
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
        text: builtins.str = ...,
        button_status: builtins.str = ...,
        toast: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["button_status", b"button_status", "icon", b"icon", "text", b"text", "toast", b"toast"]) -> None: ...

global___ButtonMeta = ButtonMeta

@typing_extensions.final
class CardBusinessBadge(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GOTO_ICON_FIELD_NUMBER: builtins.int
    BADGE_STYLE_FIELD_NUMBER: builtins.int
    @property
    def goto_icon(self) -> global___GotoIcon:
        """"""
    @property
    def badge_style(self) -> global___ReasonStyle:
        """"""
    def __init__(
        self,
        *,
        goto_icon: global___GotoIcon | None = ...,
        badge_style: global___ReasonStyle | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["badge_style", b"badge_style", "goto_icon", b"goto_icon"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge_style", b"badge_style", "goto_icon", b"goto_icon"]) -> None: ...

global___CardBusinessBadge = CardBusinessBadge

@typing_extensions.final
class ChannelLabel(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    text: builtins.str
    """"""
    uri: builtins.str
    """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["text", b"text", "uri", b"uri"]) -> None: ...

global___ChannelLabel = ChannelLabel

@typing_extensions.final
class ChannelMixedItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT1_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    GOTO_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    cover_left_icon1: builtins.int
    """"""
    cover_left_text1: builtins.str
    """"""
    cover: builtins.str
    """"""
    goto: builtins.str
    """"""
    param: builtins.str
    """"""
    uri: builtins.str
    """"""
    title: builtins.str
    """"""
    @property
    def badge(self) -> global___Badge2:
        """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        cover_left_icon1: builtins.int = ...,
        cover_left_text1: builtins.str = ...,
        cover: builtins.str = ...,
        goto: builtins.str = ...,
        param: builtins.str = ...,
        uri: builtins.str = ...,
        title: builtins.str = ...,
        badge: global___Badge2 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["badge", b"badge"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge", b"badge", "cover", b"cover", "cover_left_icon1", b"cover_left_icon1", "cover_left_text1", b"cover_left_text1", "goto", b"goto", "id", b"id", "param", b"param", "title", b"title", "uri", b"uri"]) -> None: ...

global___ChannelMixedItem = ChannelMixedItem

@typing_extensions.final
class CheckMore(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    content: builtins.str
    """"""
    uri: builtins.str
    """"""
    def __init__(
        self,
        *,
        content: builtins.str = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "uri", b"uri"]) -> None: ...

global___CheckMore = CheckMore

@typing_extensions.final
class CloudGameParams(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_FROM_FIELD_NUMBER: builtins.int
    SCENE_FIELD_NUMBER: builtins.int
    source_from: builtins.int
    """"""
    scene: builtins.str
    """"""
    def __init__(
        self,
        *,
        source_from: builtins.int = ...,
        scene: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["scene", b"scene", "source_from", b"source_from"]) -> None: ...

global___CloudGameParams = CloudGameParams

@typing_extensions.final
class DetailsRelationItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_FIELD_NUMBER: builtins.int
    COVER_BADGE_STYLE_FIELD_NUMBER: builtins.int
    MODULE_POS_FIELD_NUMBER: builtins.int
    GOTO_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    POSITION_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_V2_FIELD_NUMBER: builtins.int
    COVER_BADGE_STYLE_V2_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    cover_left_text: builtins.str
    """"""
    @property
    def cover_badge_style(self) -> global___ReasonStyle:
        """"""
    module_pos: builtins.str
    """"""
    goto: builtins.str
    """"""
    param: builtins.str
    """"""
    uri: builtins.str
    """"""
    position: builtins.int
    """"""
    cover_left_text_v2: builtins.str
    """"""
    @property
    def cover_badge_style_v2(self) -> global___ReasonStyle:
        """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        cover_left_text: builtins.str = ...,
        cover_badge_style: global___ReasonStyle | None = ...,
        module_pos: builtins.str = ...,
        goto: builtins.str = ...,
        param: builtins.str = ...,
        uri: builtins.str = ...,
        position: builtins.int = ...,
        cover_left_text_v2: builtins.str = ...,
        cover_badge_style_v2: global___ReasonStyle | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cover_badge_style", b"cover_badge_style", "cover_badge_style_v2", b"cover_badge_style_v2"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "cover_badge_style", b"cover_badge_style", "cover_badge_style_v2", b"cover_badge_style_v2", "cover_left_text", b"cover_left_text", "cover_left_text_v2", b"cover_left_text_v2", "goto", b"goto", "module_pos", b"module_pos", "param", b"param", "position", b"position", "title", b"title", "uri", b"uri"]) -> None: ...

global___DetailsRelationItem = DetailsRelationItem

@typing_extensions.final
class DislikeReason(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    name: builtins.str
    """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "name", b"name"]) -> None: ...

global___DislikeReason = DislikeReason

@typing_extensions.final
class DisplayOption(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_TITLE_ROW_FIELD_NUMBER: builtins.int
    SEARCH_PAGE_VISUAL_OPTI_FIELD_NUMBER: builtins.int
    video_title_row: builtins.int
    """"""
    search_page_visual_opti: builtins.int
    """"""
    def __init__(
        self,
        *,
        video_title_row: builtins.int = ...,
        search_page_visual_opti: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["search_page_visual_opti", b"search_page_visual_opti", "video_title_row", b"video_title_row"]) -> None: ...

global___DisplayOption = DisplayOption

@typing_extensions.final
class DyTopic(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    uri: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["title", b"title", "uri", b"uri"]) -> None: ...

global___DyTopic = DyTopic

@typing_extensions.final
class EasterEgg(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    SHOW_COUNT_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    CLOSE_COUNT_FIELD_NUMBER: builtins.int
    MASK_TRANSPARENCY_FIELD_NUMBER: builtins.int
    MASK_COLOR_FIELD_NUMBER: builtins.int
    PIC_TYPE_FIELD_NUMBER: builtins.int
    SHOW_TIME_FIELD_NUMBER: builtins.int
    SOURCE_URL_FIELD_NUMBER: builtins.int
    SOURCE_MD5_FIELD_NUMBER: builtins.int
    SOURCE_SIZE_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    show_count: builtins.int
    """"""
    type: builtins.int
    """"""
    url: builtins.str
    """"""
    close_count: builtins.int
    """"""
    mask_transparency: builtins.int
    """"""
    mask_color: builtins.str
    """"""
    pic_type: builtins.int
    """"""
    show_time: builtins.int
    """"""
    source_url: builtins.str
    """"""
    source_md5: builtins.str
    """"""
    source_size: builtins.int
    """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        show_count: builtins.int = ...,
        type: builtins.int = ...,
        url: builtins.str = ...,
        close_count: builtins.int = ...,
        mask_transparency: builtins.int = ...,
        mask_color: builtins.str = ...,
        pic_type: builtins.int = ...,
        show_time: builtins.int = ...,
        source_url: builtins.str = ...,
        source_md5: builtins.str = ...,
        source_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["close_count", b"close_count", "id", b"id", "mask_color", b"mask_color", "mask_transparency", b"mask_transparency", "pic_type", b"pic_type", "show_count", b"show_count", "show_time", b"show_time", "source_md5", b"source_md5", "source_size", b"source_size", "source_url", b"source_url", "type", b"type", "url", b"url"]) -> None: ...

global___EasterEgg = EasterEgg

@typing_extensions.final
class Episode(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URI_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    BADGES_FIELD_NUMBER: builtins.int
    POSITION_FIELD_NUMBER: builtins.int
    uri: builtins.str
    """"""
    param: builtins.str
    """"""
    index: builtins.str
    """"""
    @property
    def badges(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReasonStyle]:
        """"""
    position: builtins.int
    """"""
    def __init__(
        self,
        *,
        uri: builtins.str = ...,
        param: builtins.str = ...,
        index: builtins.str = ...,
        badges: collections.abc.Iterable[global___ReasonStyle] | None = ...,
        position: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["badges", b"badges", "index", b"index", "param", b"param", "position", b"position", "uri", b"uri"]) -> None: ...

global___Episode = Episode

@typing_extensions.final
class EpisodeNew(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    IS_NEW_FIELD_NUMBER: builtins.int
    BADGES_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    POSITION_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    uri: builtins.str
    """"""
    param: builtins.str
    """"""
    is_new: builtins.int
    """"""
    @property
    def badges(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReasonStyle]:
        """"""
    type: builtins.int
    """"""
    position: builtins.int
    """"""
    cover: builtins.str
    """"""
    label: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        uri: builtins.str = ...,
        param: builtins.str = ...,
        is_new: builtins.int = ...,
        badges: collections.abc.Iterable[global___ReasonStyle] | None = ...,
        type: builtins.int = ...,
        position: builtins.int = ...,
        cover: builtins.str = ...,
        label: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["badges", b"badges", "cover", b"cover", "is_new", b"is_new", "label", b"label", "param", b"param", "position", b"position", "title", b"title", "type", b"type", "uri", b"uri"]) -> None: ...

global___EpisodeNew = EpisodeNew

@typing_extensions.final
class ExtraLink(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    text: builtins.str
    """"""
    uri: builtins.str
    """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["text", b"text", "uri", b"uri"]) -> None: ...

global___ExtraLink = ExtraLink

@typing_extensions.final
class FollowButton(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TextsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ICON_FIELD_NUMBER: builtins.int
    TEXTS_FIELD_NUMBER: builtins.int
    STATUS_REPORT_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """"""
    @property
    def texts(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """"""
    status_report: builtins.str
    """"""
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
        texts: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        status_report: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "status_report", b"status_report", "texts", b"texts"]) -> None: ...

global___FollowButton = FollowButton

@typing_extensions.final
class FullTextResult(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    SHOW_TEXT_FIELD_NUMBER: builtins.int
    JUMP_START_PROGRESS_FIELD_NUMBER: builtins.int
    JUMP_URI_FIELD_NUMBER: builtins.int
    type: builtins.int
    """"""
    show_text: builtins.str
    """"""
    jump_start_progress: builtins.int
    """"""
    jump_uri: builtins.str
    """"""
    def __init__(
        self,
        *,
        type: builtins.int = ...,
        show_text: builtins.str = ...,
        jump_start_progress: builtins.int = ...,
        jump_uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["jump_start_progress", b"jump_start_progress", "jump_uri", b"jump_uri", "show_text", b"show_text", "type", b"type"]) -> None: ...

global___FullTextResult = FullTextResult

@typing_extensions.final
class GotoIcon(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_URL_FIELD_NUMBER: builtins.int
    ICON_NIGHT_URL_FIELD_NUMBER: builtins.int
    ICON_WIDTH_FIELD_NUMBER: builtins.int
    ICON_HEIGHT_FIELD_NUMBER: builtins.int
    icon_url: builtins.str
    """"""
    icon_night_url: builtins.str
    """"""
    icon_width: builtins.int
    """"""
    icon_height: builtins.int
    """"""
    def __init__(
        self,
        *,
        icon_url: builtins.str = ...,
        icon_night_url: builtins.str = ...,
        icon_width: builtins.int = ...,
        icon_height: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon_height", b"icon_height", "icon_night_url", b"icon_night_url", "icon_url", b"icon_url", "icon_width", b"icon_width"]) -> None: ...

global___GotoIcon = GotoIcon

@typing_extensions.final
class InlineProgressBar(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_DRAG_FIELD_NUMBER: builtins.int
    ICON_DRAG_HASH_FIELD_NUMBER: builtins.int
    ICON_STOP_FIELD_NUMBER: builtins.int
    ICON_STOP_HASH_FIELD_NUMBER: builtins.int
    icon_drag: builtins.str
    """"""
    icon_drag_hash: builtins.str
    """"""
    icon_stop: builtins.str
    """"""
    icon_stop_hash: builtins.str
    """"""
    def __init__(
        self,
        *,
        icon_drag: builtins.str = ...,
        icon_drag_hash: builtins.str = ...,
        icon_stop: builtins.str = ...,
        icon_stop_hash: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon_drag", b"icon_drag", "icon_drag_hash", b"icon_drag_hash", "icon_stop", b"icon_stop", "icon_stop_hash", b"icon_stop_hash"]) -> None: ...

global___InlineProgressBar = InlineProgressBar

@typing_extensions.final
class InlineThreePointPanel(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PANEL_TYPE_FIELD_NUMBER: builtins.int
    SHARE_ID_FIELD_NUMBER: builtins.int
    SHARE_ORIGIN_FIELD_NUMBER: builtins.int
    FUNCTIONAL_BUTTONS_FIELD_NUMBER: builtins.int
    panel_type: builtins.int
    """"""
    share_id: builtins.str
    """"""
    share_origin: builtins.str
    """"""
    @property
    def functional_buttons(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ShareButtonItem]:
        """"""
    def __init__(
        self,
        *,
        panel_type: builtins.int = ...,
        share_id: builtins.str = ...,
        share_origin: builtins.str = ...,
        functional_buttons: collections.abc.Iterable[global___ShareButtonItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["functional_buttons", b"functional_buttons", "panel_type", b"panel_type", "share_id", b"share_id", "share_origin", b"share_origin"]) -> None: ...

global___InlineThreePointPanel = InlineThreePointPanel

@typing_extensions.final
class Item(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URI_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    GOTO_FIELD_NUMBER: builtins.int
    LINKTYPE_FIELD_NUMBER: builtins.int
    POSITION_FIELD_NUMBER: builtins.int
    TRACKID_FIELD_NUMBER: builtins.int
    SPECIAL_FIELD_NUMBER: builtins.int
    ARTICLE_FIELD_NUMBER: builtins.int
    BANNER_FIELD_NUMBER: builtins.int
    LIVE_FIELD_NUMBER: builtins.int
    GAME_FIELD_NUMBER: builtins.int
    PURCHASE_FIELD_NUMBER: builtins.int
    RECOMMEND_WORD_FIELD_NUMBER: builtins.int
    DYNAMIC_FIELD_NUMBER: builtins.int
    SUGGEST_KEYWORD_FIELD_NUMBER: builtins.int
    SPECIAL_GUIDE_FIELD_NUMBER: builtins.int
    COMIC_FIELD_NUMBER: builtins.int
    CHANNEL_NEW_FIELD_NUMBER: builtins.int
    OGV_CARD_FIELD_NUMBER: builtins.int
    BANGUMI_RELATES_FIELD_NUMBER: builtins.int
    FIND_MORE_FIELD_NUMBER: builtins.int
    ESPORT_FIELD_NUMBER: builtins.int
    AUTHOR_NEW_FIELD_NUMBER: builtins.int
    TIPS_FIELD_NUMBER: builtins.int
    CM_FIELD_NUMBER: builtins.int
    PEDIA_CARD_FIELD_NUMBER: builtins.int
    UGC_INLINE_FIELD_NUMBER: builtins.int
    LIVE_INLINE_FIELD_NUMBER: builtins.int
    TOP_GAME_FIELD_NUMBER: builtins.int
    SPORTS_FIELD_NUMBER: builtins.int
    PEDIA_CARD_INLINE_FIELD_NUMBER: builtins.int
    RECOMMEND_TIPS_FIELD_NUMBER: builtins.int
    COLLECTION_CARD_FIELD_NUMBER: builtins.int
    OGV_CHANNEL_FIELD_NUMBER: builtins.int
    OGV_INLINE_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    AV_FIELD_NUMBER: builtins.int
    BANGUMI_FIELD_NUMBER: builtins.int
    ESPORTS_INLINE_FIELD_NUMBER: builtins.int
    uri: builtins.str
    """"""
    param: builtins.str
    """"""
    goto: builtins.str
    """"""
    linktype: builtins.str
    """"""
    position: builtins.int
    """"""
    trackid: builtins.str
    """"""
    @property
    def special(self) -> global___SearchSpecialCard:
        """"""
    @property
    def article(self) -> global___SearchArticleCard:
        """"""
    @property
    def banner(self) -> global___SearchBannerCard:
        """"""
    @property
    def live(self) -> global___SearchLiveCard:
        """"""
    @property
    def game(self) -> global___SearchGameCard:
        """"""
    @property
    def purchase(self) -> global___SearchPurchaseCard:
        """"""
    @property
    def recommend_word(self) -> global___SearchRecommendWordCard:
        """"""
    @property
    def dynamic(self) -> global___SearchDynamicCard:
        """"""
    @property
    def suggest_keyword(self) -> global___SearchNoResultSuggestWordCard:
        """"""
    @property
    def special_guide(self) -> global___SearchSpecialGuideCard:
        """"""
    @property
    def comic(self) -> global___SearchComicCard:
        """"""
    @property
    def channel_new(self) -> global___SearchNewChannelCard:
        """"""
    @property
    def ogv_card(self) -> global___SearchOgvCard:
        """"""
    @property
    def bangumi_relates(self) -> global___SearchOgvRelationCard:
        """"""
    @property
    def find_more(self) -> global___SearchOgvRecommendCard:
        """"""
    @property
    def esport(self) -> global___SearchSportCard:
        """"""
    @property
    def author_new(self) -> global___SearchAuthorNewCard:
        """"""
    @property
    def tips(self) -> global___SearchTipsCard:
        """"""
    @property
    def cm(self) -> global___SearchAdCard:
        """"""
    @property
    def pedia_card(self) -> global___SearchPediaCard:
        """"""
    @property
    def ugc_inline(self) -> global___SearchUgcInlineCard:
        """"""
    @property
    def live_inline(self) -> global___SearchLiveInlineCard:
        """"""
    @property
    def top_game(self) -> global___SearchTopGameCard:
        """"""
    @property
    def sports(self) -> global___SearchOlympicGameCard:
        """"""
    @property
    def pedia_card_inline(self) -> global___SearchOlympicWikiCard:
        """"""
    @property
    def recommend_tips(self) -> global___SearchRecommendTipCard:
        """"""
    @property
    def collection_card(self) -> global___SearchCollectionCard:
        """"""
    @property
    def ogv_channel(self) -> global___SearchOgvChannelCard:
        """"""
    @property
    def ogv_inline(self) -> global___SearchOgvInlineCard:
        """"""
    @property
    def author(self) -> global___SearchUpperCard:
        """"""
    @property
    def av(self) -> global___SearchVideoCard:
        """"""
    @property
    def bangumi(self) -> global___SearchBangumiCard:
        """"""
    @property
    def esports_inline(self) -> global___SearchSportInlineCard:
        """"""
    def __init__(
        self,
        *,
        uri: builtins.str = ...,
        param: builtins.str = ...,
        goto: builtins.str = ...,
        linktype: builtins.str = ...,
        position: builtins.int = ...,
        trackid: builtins.str = ...,
        special: global___SearchSpecialCard | None = ...,
        article: global___SearchArticleCard | None = ...,
        banner: global___SearchBannerCard | None = ...,
        live: global___SearchLiveCard | None = ...,
        game: global___SearchGameCard | None = ...,
        purchase: global___SearchPurchaseCard | None = ...,
        recommend_word: global___SearchRecommendWordCard | None = ...,
        dynamic: global___SearchDynamicCard | None = ...,
        suggest_keyword: global___SearchNoResultSuggestWordCard | None = ...,
        special_guide: global___SearchSpecialGuideCard | None = ...,
        comic: global___SearchComicCard | None = ...,
        channel_new: global___SearchNewChannelCard | None = ...,
        ogv_card: global___SearchOgvCard | None = ...,
        bangumi_relates: global___SearchOgvRelationCard | None = ...,
        find_more: global___SearchOgvRecommendCard | None = ...,
        esport: global___SearchSportCard | None = ...,
        author_new: global___SearchAuthorNewCard | None = ...,
        tips: global___SearchTipsCard | None = ...,
        cm: global___SearchAdCard | None = ...,
        pedia_card: global___SearchPediaCard | None = ...,
        ugc_inline: global___SearchUgcInlineCard | None = ...,
        live_inline: global___SearchLiveInlineCard | None = ...,
        top_game: global___SearchTopGameCard | None = ...,
        sports: global___SearchOlympicGameCard | None = ...,
        pedia_card_inline: global___SearchOlympicWikiCard | None = ...,
        recommend_tips: global___SearchRecommendTipCard | None = ...,
        collection_card: global___SearchCollectionCard | None = ...,
        ogv_channel: global___SearchOgvChannelCard | None = ...,
        ogv_inline: global___SearchOgvInlineCard | None = ...,
        author: global___SearchUpperCard | None = ...,
        av: global___SearchVideoCard | None = ...,
        bangumi: global___SearchBangumiCard | None = ...,
        esports_inline: global___SearchSportInlineCard | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["article", b"article", "author", b"author", "author_new", b"author_new", "av", b"av", "bangumi", b"bangumi", "bangumi_relates", b"bangumi_relates", "banner", b"banner", "card_item", b"card_item", "channel_new", b"channel_new", "cm", b"cm", "collection_card", b"collection_card", "comic", b"comic", "dynamic", b"dynamic", "esport", b"esport", "esports_inline", b"esports_inline", "find_more", b"find_more", "game", b"game", "live", b"live", "live_inline", b"live_inline", "ogv_card", b"ogv_card", "ogv_channel", b"ogv_channel", "ogv_inline", b"ogv_inline", "pedia_card", b"pedia_card", "pedia_card_inline", b"pedia_card_inline", "purchase", b"purchase", "recommend_tips", b"recommend_tips", "recommend_word", b"recommend_word", "special", b"special", "special_guide", b"special_guide", "sports", b"sports", "suggest_keyword", b"suggest_keyword", "tips", b"tips", "top_game", b"top_game", "ugc_inline", b"ugc_inline"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["article", b"article", "author", b"author", "author_new", b"author_new", "av", b"av", "bangumi", b"bangumi", "bangumi_relates", b"bangumi_relates", "banner", b"banner", "card_item", b"card_item", "channel_new", b"channel_new", "cm", b"cm", "collection_card", b"collection_card", "comic", b"comic", "dynamic", b"dynamic", "esport", b"esport", "esports_inline", b"esports_inline", "find_more", b"find_more", "game", b"game", "goto", b"goto", "linktype", b"linktype", "live", b"live", "live_inline", b"live_inline", "ogv_card", b"ogv_card", "ogv_channel", b"ogv_channel", "ogv_inline", b"ogv_inline", "param", b"param", "pedia_card", b"pedia_card", "pedia_card_inline", b"pedia_card_inline", "position", b"position", "purchase", b"purchase", "recommend_tips", b"recommend_tips", "recommend_word", b"recommend_word", "special", b"special", "special_guide", b"special_guide", "sports", b"sports", "suggest_keyword", b"suggest_keyword", "tips", b"tips", "top_game", b"top_game", "trackid", b"trackid", "ugc_inline", b"ugc_inline", "uri", b"uri"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["card_item", b"card_item"]) -> typing_extensions.Literal["special", "article", "banner", "live", "game", "purchase", "recommend_word", "dynamic", "suggest_keyword", "special_guide", "comic", "channel_new", "ogv_card", "bangumi_relates", "find_more", "esport", "author_new", "tips", "cm", "pedia_card", "ugc_inline", "live_inline", "top_game", "sports", "pedia_card_inline", "recommend_tips", "collection_card", "ogv_channel", "ogv_inline", "author", "av", "bangumi", "esports_inline"] | None: ...

global___Item = Item

@typing_extensions.final
class LikeResource(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    CONTENT_HASH_FIELD_NUMBER: builtins.int
    url: builtins.str
    """"""
    content_hash: builtins.str
    """"""
    def __init__(
        self,
        *,
        url: builtins.str = ...,
        content_hash: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content_hash", b"content_hash", "url", b"url"]) -> None: ...

global___LikeResource = LikeResource

@typing_extensions.final
class LiveBadgeResource(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    ANIMATION_URL_FIELD_NUMBER: builtins.int
    ANIMATION_URL_HASH_FIELD_NUMBER: builtins.int
    BACKGROUND_COLOR_LIGHT_FIELD_NUMBER: builtins.int
    BACKGROUND_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    ALPHA_LIGHT_FIELD_NUMBER: builtins.int
    ALPHA_NIGHT_FIELD_NUMBER: builtins.int
    FONT_COLOR_FIELD_NUMBER: builtins.int
    text: builtins.str
    """"""
    animation_url: builtins.str
    """"""
    animation_url_hash: builtins.str
    """"""
    background_color_light: builtins.str
    """"""
    background_color_night: builtins.str
    """"""
    alpha_light: builtins.int
    """"""
    alpha_night: builtins.int
    """"""
    font_color: builtins.str
    """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        animation_url: builtins.str = ...,
        animation_url_hash: builtins.str = ...,
        background_color_light: builtins.str = ...,
        background_color_night: builtins.str = ...,
        alpha_light: builtins.int = ...,
        alpha_night: builtins.int = ...,
        font_color: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["alpha_light", b"alpha_light", "alpha_night", b"alpha_night", "animation_url", b"animation_url", "animation_url_hash", b"animation_url_hash", "background_color_light", b"background_color_light", "background_color_night", b"background_color_night", "font_color", b"font_color", "text", b"text"]) -> None: ...

global___LiveBadgeResource = LiveBadgeResource

@typing_extensions.final
class Mask(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AVATAR_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    @property
    def avatar(self) -> global___Avatar:
        """"""
    @property
    def button(self) -> global___Button:
        """"""
    def __init__(
        self,
        *,
        avatar: global___Avatar | None = ...,
        button: global___Button | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["avatar", b"avatar", "button", b"button"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["avatar", b"avatar", "button", b"button"]) -> None: ...

global___Mask = Mask

@typing_extensions.final
class MatchInfoObj(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    MATCH_STAGE_FIELD_NUMBER: builtins.int
    TEAM1_FIELD_NUMBER: builtins.int
    TEAM2_FIELD_NUMBER: builtins.int
    MATCH_LABEL_FIELD_NUMBER: builtins.int
    MATCH_TIME_FIELD_NUMBER: builtins.int
    MATCH_BUTTON_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    status: builtins.int
    """"""
    match_stage: builtins.str
    """"""
    @property
    def team1(self) -> global___MatchTeam:
        """"""
    @property
    def team2(self) -> global___MatchTeam:
        """"""
    @property
    def match_label(self) -> global___MatchItem:
        """"""
    @property
    def match_time(self) -> global___MatchItem:
        """"""
    @property
    def match_button(self) -> global___MatchItem:
        """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        status: builtins.int = ...,
        match_stage: builtins.str = ...,
        team1: global___MatchTeam | None = ...,
        team2: global___MatchTeam | None = ...,
        match_label: global___MatchItem | None = ...,
        match_time: global___MatchItem | None = ...,
        match_button: global___MatchItem | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["match_button", b"match_button", "match_label", b"match_label", "match_time", b"match_time", "team1", b"team1", "team2", b"team2"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "match_button", b"match_button", "match_label", b"match_label", "match_stage", b"match_stage", "match_time", b"match_time", "status", b"status", "team1", b"team1", "team2", b"team2"]) -> None: ...

global___MatchInfoObj = MatchInfoObj

@typing_extensions.final
class MatchItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATE_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    TEXT_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    LIVE_LINK_FIELD_NUMBER: builtins.int
    TEXTS_FIELD_NUMBER: builtins.int
    state: builtins.int
    """"""
    text: builtins.str
    """"""
    text_color: builtins.str
    """"""
    text_color_night: builtins.str
    """"""
    uri: builtins.str
    """"""
    live_link: builtins.str
    """"""
    @property
    def texts(self) -> global___Texts:
        """"""
    def __init__(
        self,
        *,
        state: builtins.int = ...,
        text: builtins.str = ...,
        text_color: builtins.str = ...,
        text_color_night: builtins.str = ...,
        uri: builtins.str = ...,
        live_link: builtins.str = ...,
        texts: global___Texts | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["texts", b"texts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["live_link", b"live_link", "state", b"state", "text", b"text", "text_color", b"text_color", "text_color_night", b"text_color_night", "texts", b"texts", "uri", b"uri"]) -> None: ...

global___MatchItem = MatchItem

@typing_extensions.final
class MatchTeam(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    SCORE_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    score: builtins.int
    """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        score: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "id", b"id", "score", b"score", "title", b"title"]) -> None: ...

global___MatchTeam = MatchTeam

@typing_extensions.final
class Nav(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    PAGES_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """"""
    total: builtins.int
    """"""
    pages: builtins.int
    """"""
    type: builtins.int
    """"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        total: builtins.int = ...,
        pages: builtins.int = ...,
        type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "pages", b"pages", "total", b"total", "type", b"type"]) -> None: ...

global___Nav = Nav

@typing_extensions.final
class Navigation(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    CHILDREN_FIELD_NUMBER: builtins.int
    INLINE_CHILDREN_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    @property
    def children(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Navigation]:
        """"""
    @property
    def inline_children(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Navigation]:
        """"""
    title: builtins.str
    """"""
    uri: builtins.str
    """"""
    @property
    def button(self) -> global___NavigationButton:
        """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        children: collections.abc.Iterable[global___Navigation] | None = ...,
        inline_children: collections.abc.Iterable[global___Navigation] | None = ...,
        title: builtins.str = ...,
        uri: builtins.str = ...,
        button: global___NavigationButton | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["button", b"button"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["button", b"button", "children", b"children", "id", b"id", "inline_children", b"inline_children", "title", b"title", "uri", b"uri"]) -> None: ...

global___Navigation = Navigation

@typing_extensions.final
class NavigationButton(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    type: builtins.int
    """"""
    text: builtins.str
    """"""
    uri: builtins.str
    """"""
    def __init__(
        self,
        *,
        type: builtins.int = ...,
        text: builtins.str = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["text", b"text", "type", b"type", "uri", b"uri"]) -> None: ...

global___NavigationButton = NavigationButton

@typing_extensions.final
class NftFaceIcon(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGION_TYPE_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    SHOW_STATUS_FIELD_NUMBER: builtins.int
    region_type: builtins.int
    """"""
    icon: builtins.str
    """"""
    show_status: builtins.int
    """"""
    def __init__(
        self,
        *,
        region_type: builtins.int = ...,
        icon: builtins.str = ...,
        show_status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "region_type", b"region_type", "show_status", b"show_status"]) -> None: ...

global___NftFaceIcon = NftFaceIcon

@typing_extensions.final
class Notice(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    NOTICE_ID_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    NOTICE_TYPE_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    ICON_NIGHT_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    TEXT_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BG_COLOR_FIELD_NUMBER: builtins.int
    BG_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    notice_id: builtins.int
    """"""
    content: builtins.str
    """"""
    url: builtins.str
    """"""
    notice_type: builtins.int
    """"""
    icon: builtins.str
    """"""
    icon_night: builtins.str
    """"""
    text_color: builtins.str
    """"""
    text_color_night: builtins.str
    """"""
    bg_color: builtins.str
    """"""
    bg_color_night: builtins.str
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        notice_id: builtins.int = ...,
        content: builtins.str = ...,
        url: builtins.str = ...,
        notice_type: builtins.int = ...,
        icon: builtins.str = ...,
        icon_night: builtins.str = ...,
        text_color: builtins.str = ...,
        text_color_night: builtins.str = ...,
        bg_color: builtins.str = ...,
        bg_color_night: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_color", b"bg_color", "bg_color_night", b"bg_color_night", "content", b"content", "icon", b"icon", "icon_night", b"icon_night", "mid", b"mid", "notice_id", b"notice_id", "notice_type", b"notice_type", "text_color", b"text_color", "text_color_night", b"text_color_night", "url", b"url"]) -> None: ...

global___Notice = Notice

@typing_extensions.final
class OfficialVerify(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    type: builtins.int
    """"""
    desc: builtins.str
    """"""
    def __init__(
        self,
        *,
        type: builtins.int = ...,
        desc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc", b"desc", "type", b"type"]) -> None: ...

global___OfficialVerify = OfficialVerify

@typing_extensions.final
class OgvCardUI(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKGROUND_IMAGE_FIELD_NUMBER: builtins.int
    GAUSSIAN_BLUR_VALUE_FIELD_NUMBER: builtins.int
    MODULE_COLOR_FIELD_NUMBER: builtins.int
    background_image: builtins.str
    """"""
    gaussian_blur_value: builtins.str
    """"""
    module_color: builtins.str
    """"""
    def __init__(
        self,
        *,
        background_image: builtins.str = ...,
        gaussian_blur_value: builtins.str = ...,
        module_color: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["background_image", b"background_image", "gaussian_blur_value", b"gaussian_blur_value", "module_color", b"module_color"]) -> None: ...

global___OgvCardUI = OgvCardUI

@typing_extensions.final
class OgvClipInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAY_START_TIME_FIELD_NUMBER: builtins.int
    PLAY_END_TIME_FIELD_NUMBER: builtins.int
    play_start_time: builtins.int
    """"""
    play_end_time: builtins.int
    """"""
    def __init__(
        self,
        *,
        play_start_time: builtins.int = ...,
        play_end_time: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["play_end_time", b"play_end_time", "play_start_time", b"play_start_time"]) -> None: ...

global___OgvClipInfo = OgvClipInfo

@typing_extensions.final
class OgvRecommendWord(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    GOTO_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    goto: builtins.str
    """"""
    param: builtins.str
    """"""
    uri: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        goto: builtins.str = ...,
        param: builtins.str = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["goto", b"goto", "param", b"param", "title", b"title", "uri", b"uri"]) -> None: ...

global___OgvRecommendWord = OgvRecommendWord

@typing_extensions.final
class PediaCover(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COVER_TYPE_FIELD_NUMBER: builtins.int
    COVER_SUN_URL_FIELD_NUMBER: builtins.int
    COVER_NIGHT_URL_FIELD_NUMBER: builtins.int
    COVER_WIDTH_FIELD_NUMBER: builtins.int
    COVER_HEIGHT_FIELD_NUMBER: builtins.int
    cover_type: builtins.int
    """"""
    cover_sun_url: builtins.str
    """"""
    cover_night_url: builtins.str
    """"""
    cover_width: builtins.int
    """"""
    cover_height: builtins.int
    """"""
    def __init__(
        self,
        *,
        cover_type: builtins.int = ...,
        cover_sun_url: builtins.str = ...,
        cover_night_url: builtins.str = ...,
        cover_width: builtins.int = ...,
        cover_height: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover_height", b"cover_height", "cover_night_url", b"cover_night_url", "cover_sun_url", b"cover_sun_url", "cover_type", b"cover_type", "cover_width", b"cover_width"]) -> None: ...

global___PediaCover = PediaCover

@typing_extensions.final
class PlayerArgs(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_LIVE_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    SUB_TYPE_FIELD_NUMBER: builtins.int
    ROOM_ID_FIELD_NUMBER: builtins.int
    EP_ID_FIELD_NUMBER: builtins.int
    IS_PREVIEW_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    SEASON_ID_FIELD_NUMBER: builtins.int
    REPORT_REQUIRED_PLAY_DURATION_FIELD_NUMBER: builtins.int
    REPORT_REQUIRED_TIME_FIELD_NUMBER: builtins.int
    MANUAL_PLAY_FIELD_NUMBER: builtins.int
    HIDE_PLAY_BUTTON_FIELD_NUMBER: builtins.int
    CONTENT_MODE_FIELD_NUMBER: builtins.int
    REPORT_HISTORY_FIELD_NUMBER: builtins.int
    is_live: builtins.int
    """"""
    aid: builtins.int
    """"""
    cid: builtins.int
    """"""
    sub_type: builtins.int
    """"""
    room_id: builtins.int
    """"""
    ep_id: builtins.int
    """"""
    is_preview: builtins.int
    """"""
    type: builtins.str
    """"""
    duration: builtins.int
    """"""
    season_id: builtins.int
    """"""
    report_required_play_duration: builtins.int
    """"""
    report_required_time: builtins.int
    """"""
    manual_play: builtins.int
    """"""
    hide_play_button: builtins.bool
    """"""
    content_mode: builtins.int
    """"""
    report_history: builtins.int
    """"""
    def __init__(
        self,
        *,
        is_live: builtins.int = ...,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        sub_type: builtins.int = ...,
        room_id: builtins.int = ...,
        ep_id: builtins.int = ...,
        is_preview: builtins.int = ...,
        type: builtins.str = ...,
        duration: builtins.int = ...,
        season_id: builtins.int = ...,
        report_required_play_duration: builtins.int = ...,
        report_required_time: builtins.int = ...,
        manual_play: builtins.int = ...,
        hide_play_button: builtins.bool = ...,
        content_mode: builtins.int = ...,
        report_history: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "cid", b"cid", "content_mode", b"content_mode", "duration", b"duration", "ep_id", b"ep_id", "hide_play_button", b"hide_play_button", "is_live", b"is_live", "is_preview", b"is_preview", "manual_play", b"manual_play", "report_history", b"report_history", "report_required_play_duration", b"report_required_play_duration", "report_required_time", b"report_required_time", "room_id", b"room_id", "season_id", b"season_id", "sub_type", b"sub_type", "type", b"type"]) -> None: ...

global___PlayerArgs = PlayerArgs

@typing_extensions.final
class PlayerWidget(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    desc: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        desc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc", b"desc", "title", b"title"]) -> None: ...

global___PlayerWidget = PlayerWidget

@typing_extensions.final
class RankInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEARCH_NIGHT_ICON_URL_FIELD_NUMBER: builtins.int
    SEARCH_DAY_ICON_URL_FIELD_NUMBER: builtins.int
    SEARCH_BKG_NIGHT_COLOR_FIELD_NUMBER: builtins.int
    SEARCH_BKG_DAY_COLOR_FIELD_NUMBER: builtins.int
    SEARCH_FONT_NIGHT_COLOR_FIELD_NUMBER: builtins.int
    SEARCH_FONT_DAY_COLOR_FIELD_NUMBER: builtins.int
    RANK_CONTENT_FIELD_NUMBER: builtins.int
    RANK_LINK_FIELD_NUMBER: builtins.int
    search_night_icon_url: builtins.str
    """"""
    search_day_icon_url: builtins.str
    """"""
    search_bkg_night_color: builtins.str
    """"""
    search_bkg_day_color: builtins.str
    """"""
    search_font_night_color: builtins.str
    """"""
    search_font_day_color: builtins.str
    """"""
    rank_content: builtins.str
    """"""
    rank_link: builtins.str
    """"""
    def __init__(
        self,
        *,
        search_night_icon_url: builtins.str = ...,
        search_day_icon_url: builtins.str = ...,
        search_bkg_night_color: builtins.str = ...,
        search_bkg_day_color: builtins.str = ...,
        search_font_night_color: builtins.str = ...,
        search_font_day_color: builtins.str = ...,
        rank_content: builtins.str = ...,
        rank_link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["rank_content", b"rank_content", "rank_link", b"rank_link", "search_bkg_day_color", b"search_bkg_day_color", "search_bkg_night_color", b"search_bkg_night_color", "search_day_icon_url", b"search_day_icon_url", "search_font_day_color", b"search_font_day_color", "search_font_night_color", b"search_font_night_color", "search_night_icon_url", b"search_night_icon_url"]) -> None: ...

global___RankInfo = RankInfo

@typing_extensions.final
class RcmdReason(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    content: builtins.str
    """"""
    def __init__(
        self,
        *,
        content: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content"]) -> None: ...

global___RcmdReason = RcmdReason

@typing_extensions.final
class ReasonStyle(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    TEXT_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BG_COLOR_FIELD_NUMBER: builtins.int
    BG_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BORDER_COLOR_FIELD_NUMBER: builtins.int
    BORDER_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BG_STYLE_FIELD_NUMBER: builtins.int
    text: builtins.str
    """"""
    text_color: builtins.str
    """"""
    text_color_night: builtins.str
    """"""
    bg_color: builtins.str
    """"""
    bg_color_night: builtins.str
    """"""
    border_color: builtins.str
    """"""
    border_color_night: builtins.str
    """"""
    bg_style: builtins.int
    """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        text_color: builtins.str = ...,
        text_color_night: builtins.str = ...,
        bg_color: builtins.str = ...,
        bg_color_night: builtins.str = ...,
        border_color: builtins.str = ...,
        border_color_night: builtins.str = ...,
        bg_style: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_color", b"bg_color", "bg_color_night", b"bg_color_night", "bg_style", b"bg_style", "border_color", b"border_color", "border_color_night", b"border_color_night", "text", b"text", "text_color", b"text_color", "text_color_night", b"text_color_night"]) -> None: ...

global___ReasonStyle = ReasonStyle

@typing_extensions.final
class RecommendWord(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAM_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    FROM_SOURCE_FIELD_NUMBER: builtins.int
    param: builtins.str
    """"""
    type: builtins.str
    """"""
    title: builtins.str
    """"""
    from_source: builtins.str
    """"""
    def __init__(
        self,
        *,
        param: builtins.str = ...,
        type: builtins.str = ...,
        title: builtins.str = ...,
        from_source: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["from_source", b"from_source", "param", b"param", "title", b"title", "type", b"type"]) -> None: ...

global___RecommendWord = RecommendWord

@typing_extensions.final
class Relation(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    """"""
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["status", b"status"]) -> None: ...

global___Relation = Relation

@typing_extensions.final
class RightTopLiveBadge(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIVE_STATUS_FIELD_NUMBER: builtins.int
    IN_LIVE_FIELD_NUMBER: builtins.int
    LIVE_STATS_DESC_FIELD_NUMBER: builtins.int
    live_status: builtins.int
    """"""
    @property
    def in_live(self) -> global___LiveBadgeResource:
        """"""
    live_stats_desc: builtins.str
    """"""
    def __init__(
        self,
        *,
        live_status: builtins.int = ...,
        in_live: global___LiveBadgeResource | None = ...,
        live_stats_desc: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["in_live", b"in_live"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["in_live", b"in_live", "live_stats_desc", b"live_stats_desc", "live_status", b"live_status"]) -> None: ...

global___RightTopLiveBadge = RightTopLiveBadge

@typing_extensions.final
class SearchAdCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JSON_STR_FIELD_NUMBER: builtins.int
    json_str: builtins.str
    """"""
    def __init__(
        self,
        *,
        json_str: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["json_str", b"json_str"]) -> None: ...

global___SearchAdCard = SearchAdCard

@typing_extensions.final
class SearchAllRequest(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEYWORD_FIELD_NUMBER: builtins.int
    ORDER_FIELD_NUMBER: builtins.int
    TID_LIST_FIELD_NUMBER: builtins.int
    DURATION_LIST_FIELD_NUMBER: builtins.int
    EXTRA_WORD_FIELD_NUMBER: builtins.int
    FROM_SOURCE_FIELD_NUMBER: builtins.int
    IS_ORG_QUERY_FIELD_NUMBER: builtins.int
    LOCAL_TIME_FIELD_NUMBER: builtins.int
    AD_EXTRA_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    keyword: builtins.str
    """"""
    order: builtins.int
    """"""
    tid_list: builtins.str
    """"""
    duration_list: builtins.str
    """"""
    extra_word: builtins.str
    """"""
    from_source: builtins.str
    """"""
    is_org_query: builtins.int
    """"""
    local_time: builtins.int
    """"""
    ad_extra: builtins.str
    """"""
    @property
    def pagination(self) -> bilireq.grpc.protos.bilibili.pagination.pagination_pb2.Pagination:
        """"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
    def __init__(
        self,
        *,
        keyword: builtins.str = ...,
        order: builtins.int = ...,
        tid_list: builtins.str = ...,
        duration_list: builtins.str = ...,
        extra_word: builtins.str = ...,
        from_source: builtins.str = ...,
        is_org_query: builtins.int = ...,
        local_time: builtins.int = ...,
        ad_extra: builtins.str = ...,
        pagination: bilireq.grpc.protos.bilibili.pagination.pagination_pb2.Pagination | None = ...,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination", "player_args", b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ad_extra", b"ad_extra", "duration_list", b"duration_list", "extra_word", b"extra_word", "from_source", b"from_source", "is_org_query", b"is_org_query", "keyword", b"keyword", "local_time", b"local_time", "order", b"order", "pagination", b"pagination", "player_args", b"player_args", "tid_list", b"tid_list"]) -> None: ...

global___SearchAllRequest = SearchAllRequest

@typing_extensions.final
class SearchAllResponse(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AnnotationEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    KEYWORD_FIELD_NUMBER: builtins.int
    TRACKID_FIELD_NUMBER: builtins.int
    NAV_FIELD_NUMBER: builtins.int
    ITEM_FIELD_NUMBER: builtins.int
    EASTER_EGG_FIELD_NUMBER: builtins.int
    EXP_STR_FIELD_NUMBER: builtins.int
    EXTRA_WORD_LIST_FIELD_NUMBER: builtins.int
    ORG_EXTRA_WORD_FIELD_NUMBER: builtins.int
    SELECT_BAR_TYPE_FIELD_NUMBER: builtins.int
    NEW_SEARCH_EXP_NUM_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    APP_DISPLAY_OPTION_FIELD_NUMBER: builtins.int
    ANNOTATION_FIELD_NUMBER: builtins.int
    keyword: builtins.str
    """"""
    trackid: builtins.str
    """"""
    @property
    def nav(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Nav]:
        """"""
    @property
    def item(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Item]:
        """"""
    @property
    def easter_egg(self) -> global___EasterEgg:
        """"""
    exp_str: builtins.str
    """"""
    @property
    def extra_word_list(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    org_extra_word: builtins.str
    """"""
    select_bar_type: builtins.int
    """"""
    new_search_exp_num: builtins.int
    """"""
    @property
    def pagination(self) -> bilireq.grpc.protos.bilibili.pagination.pagination_pb2.PaginationReply:
        """"""
    @property
    def app_display_option(self) -> global___DisplayOption:
        """"""
    @property
    def annotation(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """"""
    def __init__(
        self,
        *,
        keyword: builtins.str = ...,
        trackid: builtins.str = ...,
        nav: collections.abc.Iterable[global___Nav] | None = ...,
        item: collections.abc.Iterable[global___Item] | None = ...,
        easter_egg: global___EasterEgg | None = ...,
        exp_str: builtins.str = ...,
        extra_word_list: collections.abc.Iterable[builtins.str] | None = ...,
        org_extra_word: builtins.str = ...,
        select_bar_type: builtins.int = ...,
        new_search_exp_num: builtins.int = ...,
        pagination: bilireq.grpc.protos.bilibili.pagination.pagination_pb2.PaginationReply | None = ...,
        app_display_option: global___DisplayOption | None = ...,
        annotation: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["app_display_option", b"app_display_option", "easter_egg", b"easter_egg", "pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["annotation", b"annotation", "app_display_option", b"app_display_option", "easter_egg", b"easter_egg", "exp_str", b"exp_str", "extra_word_list", b"extra_word_list", "item", b"item", "keyword", b"keyword", "nav", b"nav", "new_search_exp_num", b"new_search_exp_num", "org_extra_word", b"org_extra_word", "pagination", b"pagination", "select_bar_type", b"select_bar_type", "trackid", b"trackid"]) -> None: ...

global___SearchAllResponse = SearchAllResponse

@typing_extensions.final
class SearchArticleCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    PLAY_FIELD_NUMBER: builtins.int
    LIKE_FIELD_NUMBER: builtins.int
    REPLY_FIELD_NUMBER: builtins.int
    IMAGE_URLS_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    TEMPLATE_ID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    play: builtins.int
    """"""
    like: builtins.int
    """"""
    reply: builtins.int
    """"""
    @property
    def image_urls(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    author: builtins.str
    """"""
    template_id: builtins.int
    """"""
    id: builtins.int
    """"""
    mid: builtins.int
    """"""
    name: builtins.str
    """"""
    desc: builtins.str
    """"""
    view: builtins.int
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        play: builtins.int = ...,
        like: builtins.int = ...,
        reply: builtins.int = ...,
        image_urls: collections.abc.Iterable[builtins.str] | None = ...,
        author: builtins.str = ...,
        template_id: builtins.int = ...,
        id: builtins.int = ...,
        mid: builtins.int = ...,
        name: builtins.str = ...,
        desc: builtins.str = ...,
        view: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["author", b"author", "cover", b"cover", "desc", b"desc", "id", b"id", "image_urls", b"image_urls", "like", b"like", "mid", b"mid", "name", b"name", "play", b"play", "reply", b"reply", "template_id", b"template_id", "title", b"title", "view", b"view"]) -> None: ...

global___SearchArticleCard = SearchArticleCard

@typing_extensions.final
class SearchAuthorNewCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    LIVE_FACE_FIELD_NUMBER: builtins.int
    LIVE_URI_FIELD_NUMBER: builtins.int
    LIVE_LINK_FIELD_NUMBER: builtins.int
    FANS_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    SIGN_FIELD_NUMBER: builtins.int
    IS_UP_FIELD_NUMBER: builtins.int
    ARCHIVES_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    ROOMID_FIELD_NUMBER: builtins.int
    RELATION_FIELD_NUMBER: builtins.int
    OFFICIAL_VERIFY_FIELD_NUMBER: builtins.int
    FACE_NFT_NEW_FIELD_NUMBER: builtins.int
    NFT_FACE_ICON_FIELD_NUMBER: builtins.int
    IS_SENIOR_MEMBER_FIELD_NUMBER: builtins.int
    BACKGROUND_FIELD_NUMBER: builtins.int
    AV_STYLE_FIELD_NUMBER: builtins.int
    SPACE_FIELD_NUMBER: builtins.int
    AV_ITEMS_FIELD_NUMBER: builtins.int
    NOTICE_FIELD_NUMBER: builtins.int
    SHARE_PLANE_FIELD_NUMBER: builtins.int
    INLINE_TYPE_FIELD_NUMBER: builtins.int
    INLINE_LIVE_FIELD_NUMBER: builtins.int
    IS_INLINE_LIVE_FIELD_NUMBER: builtins.int
    THREE_POINT_FIELD_NUMBER: builtins.int
    LIVE_STATUS_FIELD_NUMBER: builtins.int
    VIP_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    live_face: builtins.int
    """"""
    live_uri: builtins.str
    """"""
    live_link: builtins.str
    """"""
    fans: builtins.int
    """"""
    level: builtins.int
    """"""
    sign: builtins.str
    """"""
    is_up: builtins.bool
    """"""
    archives: builtins.int
    """"""
    mid: builtins.int
    """"""
    roomid: builtins.int
    """"""
    @property
    def relation(self) -> global___Relation:
        """"""
    @property
    def official_verify(self) -> global___OfficialVerify:
        """"""
    face_nft_new: builtins.int
    """"""
    @property
    def nft_face_icon(self) -> global___NftFaceIcon:
        """"""
    is_senior_member: builtins.int
    """"""
    @property
    def background(self) -> global___Background:
        """"""
    av_style: builtins.int
    """"""
    @property
    def space(self) -> global___Space:
        """"""
    @property
    def av_items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AvItem]:
        """"""
    @property
    def notice(self) -> global___Notice:
        """"""
    @property
    def share_plane(self) -> global___SharePlane:
        """"""
    inline_type: builtins.str
    """"""
    @property
    def inline_live(self) -> global___SearchInlineData:
        """"""
    is_inline_live: builtins.int
    """"""
    @property
    def three_point(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ThreePoint]:
        """"""
    live_status: builtins.int
    """"""
    @property
    def vip(self) -> global___VipInfo:
        """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        live_face: builtins.int = ...,
        live_uri: builtins.str = ...,
        live_link: builtins.str = ...,
        fans: builtins.int = ...,
        level: builtins.int = ...,
        sign: builtins.str = ...,
        is_up: builtins.bool = ...,
        archives: builtins.int = ...,
        mid: builtins.int = ...,
        roomid: builtins.int = ...,
        relation: global___Relation | None = ...,
        official_verify: global___OfficialVerify | None = ...,
        face_nft_new: builtins.int = ...,
        nft_face_icon: global___NftFaceIcon | None = ...,
        is_senior_member: builtins.int = ...,
        background: global___Background | None = ...,
        av_style: builtins.int = ...,
        space: global___Space | None = ...,
        av_items: collections.abc.Iterable[global___AvItem] | None = ...,
        notice: global___Notice | None = ...,
        share_plane: global___SharePlane | None = ...,
        inline_type: builtins.str = ...,
        inline_live: global___SearchInlineData | None = ...,
        is_inline_live: builtins.int = ...,
        three_point: collections.abc.Iterable[global___ThreePoint] | None = ...,
        live_status: builtins.int = ...,
        vip: global___VipInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["background", b"background", "inline_live", b"inline_live", "nft_face_icon", b"nft_face_icon", "notice", b"notice", "official_verify", b"official_verify", "relation", b"relation", "share_plane", b"share_plane", "space", b"space", "vip", b"vip"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["archives", b"archives", "av_items", b"av_items", "av_style", b"av_style", "background", b"background", "cover", b"cover", "face_nft_new", b"face_nft_new", "fans", b"fans", "inline_live", b"inline_live", "inline_type", b"inline_type", "is_inline_live", b"is_inline_live", "is_senior_member", b"is_senior_member", "is_up", b"is_up", "level", b"level", "live_face", b"live_face", "live_link", b"live_link", "live_status", b"live_status", "live_uri", b"live_uri", "mid", b"mid", "nft_face_icon", b"nft_face_icon", "notice", b"notice", "official_verify", b"official_verify", "relation", b"relation", "roomid", b"roomid", "share_plane", b"share_plane", "sign", b"sign", "space", b"space", "three_point", b"three_point", "title", b"title", "vip", b"vip"]) -> None: ...

global___SearchAuthorNewCard = SearchAuthorNewCard

@typing_extensions.final
class SearchBangumiCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    MEDIA_TYPE_FIELD_NUMBER: builtins.int
    PLAY_STATE_FIELD_NUMBER: builtins.int
    AREA_FIELD_NUMBER: builtins.int
    STYLE_FIELD_NUMBER: builtins.int
    STYLES_FIELD_NUMBER: builtins.int
    CV_FIELD_NUMBER: builtins.int
    RATING_FIELD_NUMBER: builtins.int
    VOTE_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    STAFF_FIELD_NUMBER: builtins.int
    PROMPT_FIELD_NUMBER: builtins.int
    PTIME_FIELD_NUMBER: builtins.int
    SEASON_TYPE_NAME_FIELD_NUMBER: builtins.int
    EPISODES_FIELD_NUMBER: builtins.int
    IS_SELECTION_FIELD_NUMBER: builtins.int
    IS_ATTEN_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    SEASON_ID_FIELD_NUMBER: builtins.int
    OUT_NAME_FIELD_NUMBER: builtins.int
    OUT_ICON_FIELD_NUMBER: builtins.int
    OUT_URL_FIELD_NUMBER: builtins.int
    BADGES_FIELD_NUMBER: builtins.int
    IS_OUT_FIELD_NUMBER: builtins.int
    EPISODES_NEW_FIELD_NUMBER: builtins.int
    WATCH_BUTTON_FIELD_NUMBER: builtins.int
    SELECTION_STYLE_FIELD_NUMBER: builtins.int
    CHECK_MORE_FIELD_NUMBER: builtins.int
    FOLLOW_BUTTON_FIELD_NUMBER: builtins.int
    STYLE_LABEL_FIELD_NUMBER: builtins.int
    BADGES_V2_FIELD_NUMBER: builtins.int
    STYLES_V2_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    media_type: builtins.int
    """"""
    play_state: builtins.int
    """"""
    area: builtins.str
    """"""
    style: builtins.str
    """"""
    styles: builtins.str
    """"""
    cv: builtins.str
    """"""
    rating: builtins.float
    """"""
    vote: builtins.int
    """"""
    target: builtins.str
    """"""
    staff: builtins.str
    """"""
    prompt: builtins.str
    """"""
    ptime: builtins.int
    """"""
    season_type_name: builtins.str
    """"""
    @property
    def episodes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Episode]:
        """"""
    is_selection: builtins.int
    """"""
    is_atten: builtins.int
    """"""
    label: builtins.str
    """"""
    season_id: builtins.int
    """"""
    out_name: builtins.str
    """"""
    out_icon: builtins.str
    """"""
    out_url: builtins.str
    """"""
    @property
    def badges(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReasonStyle]:
        """"""
    is_out: builtins.int
    """"""
    @property
    def episodes_new(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EpisodeNew]:
        """"""
    @property
    def watch_button(self) -> global___WatchButton:
        """"""
    selection_style: builtins.str
    """"""
    @property
    def check_more(self) -> global___CheckMore:
        """"""
    @property
    def follow_button(self) -> global___FollowButton:
        """"""
    @property
    def style_label(self) -> global___ReasonStyle:
        """"""
    @property
    def badges_v2(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReasonStyle]:
        """"""
    styles_v2: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        media_type: builtins.int = ...,
        play_state: builtins.int = ...,
        area: builtins.str = ...,
        style: builtins.str = ...,
        styles: builtins.str = ...,
        cv: builtins.str = ...,
        rating: builtins.float = ...,
        vote: builtins.int = ...,
        target: builtins.str = ...,
        staff: builtins.str = ...,
        prompt: builtins.str = ...,
        ptime: builtins.int = ...,
        season_type_name: builtins.str = ...,
        episodes: collections.abc.Iterable[global___Episode] | None = ...,
        is_selection: builtins.int = ...,
        is_atten: builtins.int = ...,
        label: builtins.str = ...,
        season_id: builtins.int = ...,
        out_name: builtins.str = ...,
        out_icon: builtins.str = ...,
        out_url: builtins.str = ...,
        badges: collections.abc.Iterable[global___ReasonStyle] | None = ...,
        is_out: builtins.int = ...,
        episodes_new: collections.abc.Iterable[global___EpisodeNew] | None = ...,
        watch_button: global___WatchButton | None = ...,
        selection_style: builtins.str = ...,
        check_more: global___CheckMore | None = ...,
        follow_button: global___FollowButton | None = ...,
        style_label: global___ReasonStyle | None = ...,
        badges_v2: collections.abc.Iterable[global___ReasonStyle] | None = ...,
        styles_v2: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["check_more", b"check_more", "follow_button", b"follow_button", "style_label", b"style_label", "watch_button", b"watch_button"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["area", b"area", "badges", b"badges", "badges_v2", b"badges_v2", "check_more", b"check_more", "cover", b"cover", "cv", b"cv", "episodes", b"episodes", "episodes_new", b"episodes_new", "follow_button", b"follow_button", "is_atten", b"is_atten", "is_out", b"is_out", "is_selection", b"is_selection", "label", b"label", "media_type", b"media_type", "out_icon", b"out_icon", "out_name", b"out_name", "out_url", b"out_url", "play_state", b"play_state", "prompt", b"prompt", "ptime", b"ptime", "rating", b"rating", "season_id", b"season_id", "season_type_name", b"season_type_name", "selection_style", b"selection_style", "staff", b"staff", "style", b"style", "style_label", b"style_label", "styles", b"styles", "styles_v2", b"styles_v2", "target", b"target", "title", b"title", "vote", b"vote", "watch_button", b"watch_button"]) -> None: ...

global___SearchBangumiCard = SearchBangumiCard

@typing_extensions.final
class SearchBannerCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "title", b"title"]) -> None: ...

global___SearchBannerCard = SearchBannerCard

@typing_extensions.final
class SearchByTypeRequest(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _CategorySort:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _CategorySortEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[SearchByTypeRequest._CategorySort.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        CATEGORY_SORT_DEFAULT: SearchByTypeRequest._CategorySort.ValueType  # 0
        CATEGORY_SORT_PUBLISH_TIME: SearchByTypeRequest._CategorySort.ValueType  # 1
        CATEGORY_SORT_CLICK_COUNT: SearchByTypeRequest._CategorySort.ValueType  # 2
        CATEGORY_SORT_COMMENT_COUNT: SearchByTypeRequest._CategorySort.ValueType  # 3
        CATEGORY_SORT_LIKE_COUNT: SearchByTypeRequest._CategorySort.ValueType  # 4

    class CategorySort(_CategorySort, metaclass=_CategorySortEnumTypeWrapper): ...
    CATEGORY_SORT_DEFAULT: SearchByTypeRequest.CategorySort.ValueType  # 0
    CATEGORY_SORT_PUBLISH_TIME: SearchByTypeRequest.CategorySort.ValueType  # 1
    CATEGORY_SORT_CLICK_COUNT: SearchByTypeRequest.CategorySort.ValueType  # 2
    CATEGORY_SORT_COMMENT_COUNT: SearchByTypeRequest.CategorySort.ValueType  # 3
    CATEGORY_SORT_LIKE_COUNT: SearchByTypeRequest.CategorySort.ValueType  # 4

    class _UserType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _UserTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[SearchByTypeRequest._UserType.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ALL: SearchByTypeRequest._UserType.ValueType  # 0
        UP: SearchByTypeRequest._UserType.ValueType  # 1
        NORMAL_USER: SearchByTypeRequest._UserType.ValueType  # 2
        AUTHENTICATED_USER: SearchByTypeRequest._UserType.ValueType  # 3

    class UserType(_UserType, metaclass=_UserTypeEnumTypeWrapper): ...
    ALL: SearchByTypeRequest.UserType.ValueType  # 0
    UP: SearchByTypeRequest.UserType.ValueType  # 1
    NORMAL_USER: SearchByTypeRequest.UserType.ValueType  # 2
    AUTHENTICATED_USER: SearchByTypeRequest.UserType.ValueType  # 3

    class _UserSort:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _UserSortEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[SearchByTypeRequest._UserSort.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        USER_SORT_DEFAULT: SearchByTypeRequest._UserSort.ValueType  # 0
        USER_SORT_FANS_DESCEND: SearchByTypeRequest._UserSort.ValueType  # 1
        USER_SORT_FANS_ASCEND: SearchByTypeRequest._UserSort.ValueType  # 2
        USER_SORT_LEVEL_DESCEND: SearchByTypeRequest._UserSort.ValueType  # 3
        USER_SORT_LEVEL_ASCEND: SearchByTypeRequest._UserSort.ValueType  # 4

    class UserSort(_UserSort, metaclass=_UserSortEnumTypeWrapper): ...
    USER_SORT_DEFAULT: SearchByTypeRequest.UserSort.ValueType  # 0
    USER_SORT_FANS_DESCEND: SearchByTypeRequest.UserSort.ValueType  # 1
    USER_SORT_FANS_ASCEND: SearchByTypeRequest.UserSort.ValueType  # 2
    USER_SORT_LEVEL_DESCEND: SearchByTypeRequest.UserSort.ValueType  # 3
    USER_SORT_LEVEL_ASCEND: SearchByTypeRequest.UserSort.ValueType  # 4

    TYPE_FIELD_NUMBER: builtins.int
    KEYWORD_FIELD_NUMBER: builtins.int
    CATEGORY_SORT_FIELD_NUMBER: builtins.int
    CATEGORY_ID_FIELD_NUMBER: builtins.int
    USER_TYPE_FIELD_NUMBER: builtins.int
    USER_SORT_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    type: builtins.int
    """搜索目标类型, 番剧为7"""
    keyword: builtins.str
    """关键词"""
    category_sort: global___SearchByTypeRequest.CategorySort.ValueType
    """"""
    category_id: builtins.int
    """"""
    user_type: global___SearchByTypeRequest.UserType.ValueType
    """"""
    user_sort: global___SearchByTypeRequest.UserSort.ValueType
    """"""
    @property
    def pagination(self) -> bilireq.grpc.protos.bilibili.pagination.pagination_pb2.Pagination:
        """"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
    def __init__(
        self,
        *,
        type: builtins.int = ...,
        keyword: builtins.str = ...,
        category_sort: global___SearchByTypeRequest.CategorySort.ValueType = ...,
        category_id: builtins.int = ...,
        user_type: global___SearchByTypeRequest.UserType.ValueType = ...,
        user_sort: global___SearchByTypeRequest.UserSort.ValueType = ...,
        pagination: bilireq.grpc.protos.bilibili.pagination.pagination_pb2.Pagination | None = ...,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination", "player_args", b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["category_id", b"category_id", "category_sort", b"category_sort", "keyword", b"keyword", "pagination", b"pagination", "player_args", b"player_args", "type", b"type", "user_sort", b"user_sort", "user_type", b"user_type"]) -> None: ...

global___SearchByTypeRequest = SearchByTypeRequest

@typing_extensions.final
class SearchByTypeResponse(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AnnotationEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TRACKID_FIELD_NUMBER: builtins.int
    PAGES_FIELD_NUMBER: builtins.int
    EXP_STR_FIELD_NUMBER: builtins.int
    KEYWORD_FIELD_NUMBER: builtins.int
    RESULT_IS_RECOMMEND_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    ANNOTATION_FIELD_NUMBER: builtins.int
    trackid: builtins.str
    """追踪id"""
    pages: builtins.int
    """当前页码"""
    exp_str: builtins.str
    """"""
    keyword: builtins.str
    """搜索关键词"""
    result_is_recommend: builtins.int
    """是否为推荐结果"""
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Item]:
        """搜索结果条目"""
    @property
    def pagination(self) -> bilireq.grpc.protos.bilibili.pagination.pagination_pb2.PaginationReply:
        """分页信息"""
    @property
    def annotation(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """"""
    def __init__(
        self,
        *,
        trackid: builtins.str = ...,
        pages: builtins.int = ...,
        exp_str: builtins.str = ...,
        keyword: builtins.str = ...,
        result_is_recommend: builtins.int = ...,
        items: collections.abc.Iterable[global___Item] | None = ...,
        pagination: bilireq.grpc.protos.bilibili.pagination.pagination_pb2.PaginationReply | None = ...,
        annotation: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["annotation", b"annotation", "exp_str", b"exp_str", "items", b"items", "keyword", b"keyword", "pages", b"pages", "pagination", b"pagination", "result_is_recommend", b"result_is_recommend", "trackid", b"trackid"]) -> None: ...

global___SearchByTypeResponse = SearchByTypeResponse

@typing_extensions.final
class SearchCollectionCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    AV_ITEMS_FIELD_NUMBER: builtins.int
    BOTTOM_BUTTON_FIELD_NUMBER: builtins.int
    COLLECTION_ICON_FIELD_NUMBER: builtins.int
    SHOW_CARD_DESC1_FIELD_NUMBER: builtins.int
    SHOW_CARD_DESC2_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    author: builtins.str
    """"""
    @property
    def av_items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AvItem]:
        """"""
    @property
    def bottom_button(self) -> global___BottomButton:
        """"""
    collection_icon: builtins.str
    """"""
    show_card_desc1: builtins.str
    """"""
    show_card_desc2: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        author: builtins.str = ...,
        av_items: collections.abc.Iterable[global___AvItem] | None = ...,
        bottom_button: global___BottomButton | None = ...,
        collection_icon: builtins.str = ...,
        show_card_desc1: builtins.str = ...,
        show_card_desc2: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bottom_button", b"bottom_button"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["author", b"author", "av_items", b"av_items", "bottom_button", b"bottom_button", "collection_icon", b"collection_icon", "cover", b"cover", "show_card_desc1", b"show_card_desc1", "show_card_desc2", b"show_card_desc2", "title", b"title"]) -> None: ...

global___SearchCollectionCard = SearchCollectionCard

@typing_extensions.final
class SearchComicCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    STYLE_FIELD_NUMBER: builtins.int
    COMIC_URL_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    name: builtins.str
    """"""
    style: builtins.str
    """"""
    comic_url: builtins.str
    """"""
    badge: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        name: builtins.str = ...,
        style: builtins.str = ...,
        comic_url: builtins.str = ...,
        badge: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge", b"badge", "comic_url", b"comic_url", "cover", b"cover", "name", b"name", "style", b"style", "title", b"title"]) -> None: ...

global___SearchComicCard = SearchComicCard

@typing_extensions.final
class SearchComicInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URI_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    COMIC_FIELD_NUMBER: builtins.int
    uri: builtins.str
    """"""
    param: builtins.str
    """"""
    @property
    def comic(self) -> global___SearchComicCard:
        """"""
    def __init__(
        self,
        *,
        uri: builtins.str = ...,
        param: builtins.str = ...,
        comic: global___SearchComicCard | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["comic", b"comic"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["comic", b"comic", "param", b"param", "uri", b"uri"]) -> None: ...

global___SearchComicInfo = SearchComicInfo

@typing_extensions.final
class SearchComicRequest(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_LIST_FIELD_NUMBER: builtins.int
    id_list: builtins.str
    """"""
    def __init__(
        self,
        *,
        id_list: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id_list", b"id_list"]) -> None: ...

global___SearchComicRequest = SearchComicRequest

@typing_extensions.final
class SearchComicResponse(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEMS_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SearchComicInfo]:
        """"""
    def __init__(
        self,
        *,
        items: collections.abc.Iterable[global___SearchComicInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["items", b"items"]) -> None: ...

global___SearchComicResponse = SearchComicResponse

@typing_extensions.final
class SearchDynamicCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    COVER_COUNT_FIELD_NUMBER: builtins.int
    COVERS_FIELD_NUMBER: builtins.int
    UPPER_FIELD_NUMBER: builtins.int
    STAT_FIELD_NUMBER: builtins.int
    DY_TOPIC_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    cover_count: builtins.int
    """"""
    @property
    def covers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    @property
    def upper(self) -> global___Upper:
        """"""
    @property
    def stat(self) -> global___Stat:
        """"""
    @property
    def dy_topic(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DyTopic]:
        """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        cover_count: builtins.int = ...,
        covers: collections.abc.Iterable[builtins.str] | None = ...,
        upper: global___Upper | None = ...,
        stat: global___Stat | None = ...,
        dy_topic: collections.abc.Iterable[global___DyTopic] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["stat", b"stat", "upper", b"upper"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "cover_count", b"cover_count", "covers", b"covers", "dy_topic", b"dy_topic", "stat", b"stat", "title", b"title", "upper", b"upper"]) -> None: ...

global___SearchDynamicCard = SearchDynamicCard

@typing_extensions.final
class SearchGameCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    RESERVE_FIELD_NUMBER: builtins.int
    RATING_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NOTICE_NAME_FIELD_NUMBER: builtins.int
    NOTICE_CONTENT_FIELD_NUMBER: builtins.int
    GIFT_CONTENT_FIELD_NUMBER: builtins.int
    GIFT_URL_FIELD_NUMBER: builtins.int
    RESERVE_STATUS_FIELD_NUMBER: builtins.int
    RANK_INFO_FIELD_NUMBER: builtins.int
    SPECIAL_BG_COLOR_FIELD_NUMBER: builtins.int
    CLOUD_GAME_PARAMS_FIELD_NUMBER: builtins.int
    SHOW_CLOUD_GAME_ENTRY_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    reserve: builtins.str
    """"""
    rating: builtins.float
    """"""
    tags: builtins.str
    """"""
    notice_name: builtins.str
    """"""
    notice_content: builtins.str
    """"""
    gift_content: builtins.str
    """"""
    gift_url: builtins.str
    """"""
    reserve_status: builtins.int
    """"""
    @property
    def rank_info(self) -> global___RankInfo:
        """"""
    special_bg_color: builtins.str
    """"""
    @property
    def cloud_game_params(self) -> global___CloudGameParams:
        """"""
    show_cloud_game_entry: builtins.bool
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        reserve: builtins.str = ...,
        rating: builtins.float = ...,
        tags: builtins.str = ...,
        notice_name: builtins.str = ...,
        notice_content: builtins.str = ...,
        gift_content: builtins.str = ...,
        gift_url: builtins.str = ...,
        reserve_status: builtins.int = ...,
        rank_info: global___RankInfo | None = ...,
        special_bg_color: builtins.str = ...,
        cloud_game_params: global___CloudGameParams | None = ...,
        show_cloud_game_entry: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cloud_game_params", b"cloud_game_params", "rank_info", b"rank_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_game_params", b"cloud_game_params", "cover", b"cover", "gift_content", b"gift_content", "gift_url", b"gift_url", "notice_content", b"notice_content", "notice_name", b"notice_name", "rank_info", b"rank_info", "rating", b"rating", "reserve", b"reserve", "reserve_status", b"reserve_status", "show_cloud_game_entry", b"show_cloud_game_entry", "special_bg_color", b"special_bg_color", "tags", b"tags", "title", b"title"]) -> None: ...

global___SearchGameCard = SearchGameCard

@typing_extensions.final
class SearchInlineData(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URI_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    CAN_PLAY_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    CARD_GOTO_FIELD_NUMBER: builtins.int
    CARD_TYPE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON1_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON2_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT2_FIELD_NUMBER: builtins.int
    UP_ARGS_FIELD_NUMBER: builtins.int
    EXTRA_URI_FIELD_NUMBER: builtins.int
    IS_FAV_FIELD_NUMBER: builtins.int
    IS_COIN_FIELD_NUMBER: builtins.int
    GOTO_FIELD_NUMBER: builtins.int
    SHARE_FIELD_NUMBER: builtins.int
    THREE_POINT_FIELD_NUMBER: builtins.int
    THREE_POINT_V2_FIELD_NUMBER: builtins.int
    SHARE_PLANE_FIELD_NUMBER: builtins.int
    THREE_POINT_META_FIELD_NUMBER: builtins.int
    AVATAR_FIELD_NUMBER: builtins.int
    COVER_RIGHT_TEXT_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    INLINE_PROGRESS_BAR_FIELD_NUMBER: builtins.int
    LIKE_BUTTON_FIELD_NUMBER: builtins.int
    OFFICIAL_ICON_FIELD_NUMBER: builtins.int
    OFFICIAL_ICON_V2_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    TRAFFIC_CONFIG_FIELD_NUMBER: builtins.int
    IS_ATTEN_FIELD_NUMBER: builtins.int
    GOTO_ICON_FIELD_NUMBER: builtins.int
    DISABLE_DANMAKU_FIELD_NUMBER: builtins.int
    HIDE_DANMAKU_SWITCH_FIELD_NUMBER: builtins.int
    BADGE_STYLE_FIELD_NUMBER: builtins.int
    PLAYER_WIDGET_FIELD_NUMBER: builtins.int
    COVER_BADGE_STYLE_FIELD_NUMBER: builtins.int
    RIGHT_TOP_LIVE_BADGE_FIELD_NUMBER: builtins.int
    uri: builtins.str
    """"""
    title: builtins.str
    """"""
    @property
    def player_args(self) -> global___PlayerArgs:
        """"""
    can_play: builtins.int
    """"""
    @property
    def args(self) -> global___Args:
        """"""
    card_goto: builtins.str
    """"""
    card_type: builtins.str
    """"""
    cover: builtins.str
    """"""
    cover_left_icon1: builtins.int
    """"""
    cover_left_icon2: builtins.int
    """"""
    cover_left_text1: builtins.str
    """"""
    cover_left_text2: builtins.str
    """"""
    @property
    def up_args(self) -> global___UpArgs:
        """"""
    extra_uri: builtins.str
    """"""
    is_fav: builtins.bool
    """"""
    is_coin: builtins.bool
    """"""
    goto: builtins.str
    """"""
    @property
    def share(self) -> global___Share:
        """"""
    @property
    def three_point(self) -> global___ThreePoint2:
        """"""
    @property
    def three_point_v2(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ThreePointV2]:
        """"""
    @property
    def share_plane(self) -> global___SharePlane:
        """"""
    @property
    def three_point_meta(self) -> global___InlineThreePointPanel:
        """"""
    @property
    def avatar(self) -> global___Avatar:
        """"""
    cover_right_text: builtins.str
    """"""
    desc: builtins.str
    """"""
    @property
    def inline_progress_bar(self) -> global___InlineProgressBar:
        """"""
    @property
    def like_button(self) -> global___SearchLikeButtonItem:
        """"""
    official_icon: builtins.int
    """"""
    official_icon_v2: builtins.int
    """"""
    param: builtins.str
    """"""
    @property
    def traffic_config(self) -> global___TrafficConfig:
        """"""
    is_atten: builtins.bool
    """"""
    @property
    def goto_icon(self) -> global___GotoIcon:
        """"""
    disable_danmaku: builtins.bool
    """"""
    hide_danmaku_switch: builtins.bool
    """"""
    @property
    def badge_style(self) -> global___ReasonStyle:
        """"""
    @property
    def player_widget(self) -> global___PlayerWidget:
        """"""
    @property
    def cover_badge_style(self) -> global___ReasonStyle:
        """"""
    @property
    def right_top_live_badge(self) -> global___RightTopLiveBadge:
        """"""
    def __init__(
        self,
        *,
        uri: builtins.str = ...,
        title: builtins.str = ...,
        player_args: global___PlayerArgs | None = ...,
        can_play: builtins.int = ...,
        args: global___Args | None = ...,
        card_goto: builtins.str = ...,
        card_type: builtins.str = ...,
        cover: builtins.str = ...,
        cover_left_icon1: builtins.int = ...,
        cover_left_icon2: builtins.int = ...,
        cover_left_text1: builtins.str = ...,
        cover_left_text2: builtins.str = ...,
        up_args: global___UpArgs | None = ...,
        extra_uri: builtins.str = ...,
        is_fav: builtins.bool = ...,
        is_coin: builtins.bool = ...,
        goto: builtins.str = ...,
        share: global___Share | None = ...,
        three_point: global___ThreePoint2 | None = ...,
        three_point_v2: collections.abc.Iterable[global___ThreePointV2] | None = ...,
        share_plane: global___SharePlane | None = ...,
        three_point_meta: global___InlineThreePointPanel | None = ...,
        avatar: global___Avatar | None = ...,
        cover_right_text: builtins.str = ...,
        desc: builtins.str = ...,
        inline_progress_bar: global___InlineProgressBar | None = ...,
        like_button: global___SearchLikeButtonItem | None = ...,
        official_icon: builtins.int = ...,
        official_icon_v2: builtins.int = ...,
        param: builtins.str = ...,
        traffic_config: global___TrafficConfig | None = ...,
        is_atten: builtins.bool = ...,
        goto_icon: global___GotoIcon | None = ...,
        disable_danmaku: builtins.bool = ...,
        hide_danmaku_switch: builtins.bool = ...,
        badge_style: global___ReasonStyle | None = ...,
        player_widget: global___PlayerWidget | None = ...,
        cover_badge_style: global___ReasonStyle | None = ...,
        right_top_live_badge: global___RightTopLiveBadge | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["args", b"args", "avatar", b"avatar", "badge_style", b"badge_style", "cover_badge_style", b"cover_badge_style", "goto_icon", b"goto_icon", "inline_progress_bar", b"inline_progress_bar", "like_button", b"like_button", "player_args", b"player_args", "player_widget", b"player_widget", "right_top_live_badge", b"right_top_live_badge", "share", b"share", "share_plane", b"share_plane", "three_point", b"three_point", "three_point_meta", b"three_point_meta", "traffic_config", b"traffic_config", "up_args", b"up_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["args", b"args", "avatar", b"avatar", "badge_style", b"badge_style", "can_play", b"can_play", "card_goto", b"card_goto", "card_type", b"card_type", "cover", b"cover", "cover_badge_style", b"cover_badge_style", "cover_left_icon1", b"cover_left_icon1", "cover_left_icon2", b"cover_left_icon2", "cover_left_text1", b"cover_left_text1", "cover_left_text2", b"cover_left_text2", "cover_right_text", b"cover_right_text", "desc", b"desc", "disable_danmaku", b"disable_danmaku", "extra_uri", b"extra_uri", "goto", b"goto", "goto_icon", b"goto_icon", "hide_danmaku_switch", b"hide_danmaku_switch", "inline_progress_bar", b"inline_progress_bar", "is_atten", b"is_atten", "is_coin", b"is_coin", "is_fav", b"is_fav", "like_button", b"like_button", "official_icon", b"official_icon", "official_icon_v2", b"official_icon_v2", "param", b"param", "player_args", b"player_args", "player_widget", b"player_widget", "right_top_live_badge", b"right_top_live_badge", "share", b"share", "share_plane", b"share_plane", "three_point", b"three_point", "three_point_meta", b"three_point_meta", "three_point_v2", b"three_point_v2", "title", b"title", "traffic_config", b"traffic_config", "up_args", b"up_args", "uri", b"uri"]) -> None: ...

global___SearchInlineData = SearchInlineData

@typing_extensions.final
class SearchLikeButtonItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    SELECTED_FIELD_NUMBER: builtins.int
    SHOW_COUNT_FIELD_NUMBER: builtins.int
    LIKE_RESOURCE_FIELD_NUMBER: builtins.int
    LIKE_NIGHT_RESOURCE_FIELD_NUMBER: builtins.int
    DISLIKE_RESOURCE_FIELD_NUMBER: builtins.int
    DISLIKE_NIGHT_RESOURCE_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""
    count: builtins.int
    """"""
    selected: builtins.int
    """"""
    show_count: builtins.bool
    """"""
    @property
    def like_resource(self) -> global___LikeResource:
        """"""
    @property
    def like_night_resource(self) -> global___LikeResource:
        """"""
    @property
    def dislike_resource(self) -> global___LikeResource:
        """"""
    @property
    def dislike_night_resource(self) -> global___LikeResource:
        """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        count: builtins.int = ...,
        selected: builtins.int = ...,
        show_count: builtins.bool = ...,
        like_resource: global___LikeResource | None = ...,
        like_night_resource: global___LikeResource | None = ...,
        dislike_resource: global___LikeResource | None = ...,
        dislike_night_resource: global___LikeResource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dislike_night_resource", b"dislike_night_resource", "dislike_resource", b"dislike_resource", "like_night_resource", b"like_night_resource", "like_resource", b"like_resource"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "count", b"count", "dislike_night_resource", b"dislike_night_resource", "dislike_resource", b"dislike_resource", "like_night_resource", b"like_night_resource", "like_resource", b"like_resource", "selected", b"selected", "show_count", b"show_count"]) -> None: ...

global___SearchLikeButtonItem = SearchLikeButtonItem

@typing_extensions.final
class SearchLiveCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    RCMD_REASON_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ONLINE_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    LIVE_LINK_FIELD_NUMBER: builtins.int
    CARD_LEFT_TEXT_FIELD_NUMBER: builtins.int
    CARD_LEFT_ICON_FIELD_NUMBER: builtins.int
    SHOW_CARD_DESC2_FIELD_NUMBER: builtins.int
    RIGHT_TOP_LIVE_BADGE_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    @property
    def rcmd_reason(self) -> global___RcmdReason:
        """"""
    name: builtins.str
    """"""
    online: builtins.int
    """"""
    badge: builtins.str
    """"""
    live_link: builtins.str
    """"""
    card_left_text: builtins.str
    """"""
    card_left_icon: builtins.int
    """"""
    show_card_desc2: builtins.str
    """"""
    @property
    def right_top_live_badge(self) -> global___RightTopLiveBadge:
        """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        rcmd_reason: global___RcmdReason | None = ...,
        name: builtins.str = ...,
        online: builtins.int = ...,
        badge: builtins.str = ...,
        live_link: builtins.str = ...,
        card_left_text: builtins.str = ...,
        card_left_icon: builtins.int = ...,
        show_card_desc2: builtins.str = ...,
        right_top_live_badge: global___RightTopLiveBadge | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["rcmd_reason", b"rcmd_reason", "right_top_live_badge", b"right_top_live_badge"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge", b"badge", "card_left_icon", b"card_left_icon", "card_left_text", b"card_left_text", "cover", b"cover", "live_link", b"live_link", "name", b"name", "online", b"online", "rcmd_reason", b"rcmd_reason", "right_top_live_badge", b"right_top_live_badge", "show_card_desc2", b"show_card_desc2", "title", b"title"]) -> None: ...

global___SearchLiveCard = SearchLiveCard

@typing_extensions.final
class SearchLiveInlineCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    RCMD_REASON_STYLE_FIELD_NUMBER: builtins.int
    ROOMID_FIELD_NUMBER: builtins.int
    LIVE_LINK_FIELD_NUMBER: builtins.int
    LIVE_ROOM_INLINE_FIELD_NUMBER: builtins.int
    INLINE_TYPE_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    mid: builtins.int
    """"""
    @property
    def rcmd_reason_style(self) -> global___ReasonStyle:
        """"""
    roomid: builtins.int
    """"""
    live_link: builtins.str
    """"""
    @property
    def live_room_inline(self) -> global___SearchInlineData:
        """"""
    inline_type: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        mid: builtins.int = ...,
        rcmd_reason_style: global___ReasonStyle | None = ...,
        roomid: builtins.int = ...,
        live_link: builtins.str = ...,
        live_room_inline: global___SearchInlineData | None = ...,
        inline_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["live_room_inline", b"live_room_inline", "rcmd_reason_style", b"rcmd_reason_style"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "inline_type", b"inline_type", "live_link", b"live_link", "live_room_inline", b"live_room_inline", "mid", b"mid", "rcmd_reason_style", b"rcmd_reason_style", "roomid", b"roomid", "title", b"title"]) -> None: ...

global___SearchLiveInlineCard = SearchLiveInlineCard

@typing_extensions.final
class SearchNewChannelCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    TYPE_ICON_FIELD_NUMBER: builtins.int
    CHANNEL_LABEL1_FIELD_NUMBER: builtins.int
    CHANNEL_LABEL2_FIELD_NUMBER: builtins.int
    CHANNEL_BUTTON_FIELD_NUMBER: builtins.int
    DESIGN_TYPE_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    id: builtins.int
    """"""
    type_icon: builtins.str
    """"""
    @property
    def channel_label1(self) -> global___ChannelLabel:
        """"""
    @property
    def channel_label2(self) -> global___ChannelLabel:
        """"""
    @property
    def channel_button(self) -> global___ChannelLabel:
        """"""
    design_type: builtins.str
    """"""
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ChannelMixedItem]:
        """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        id: builtins.int = ...,
        type_icon: builtins.str = ...,
        channel_label1: global___ChannelLabel | None = ...,
        channel_label2: global___ChannelLabel | None = ...,
        channel_button: global___ChannelLabel | None = ...,
        design_type: builtins.str = ...,
        items: collections.abc.Iterable[global___ChannelMixedItem] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["channel_button", b"channel_button", "channel_label1", b"channel_label1", "channel_label2", b"channel_label2"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["channel_button", b"channel_button", "channel_label1", b"channel_label1", "channel_label2", b"channel_label2", "cover", b"cover", "design_type", b"design_type", "id", b"id", "items", b"items", "title", b"title", "type_icon", b"type_icon"]) -> None: ...

global___SearchNewChannelCard = SearchNewChannelCard

@typing_extensions.final
class SearchNoResultSuggestWordCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    SUG_KEY_WORD_TYPE_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    sug_key_word_type: builtins.int
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        sug_key_word_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "sug_key_word_type", b"sug_key_word_type", "title", b"title"]) -> None: ...

global___SearchNoResultSuggestWordCard = SearchNoResultSuggestWordCard

@typing_extensions.final
class SearchOgvCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    SUB_TITLE1_FIELD_NUMBER: builtins.int
    SUB_TITLE2_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    BG_COVER_FIELD_NUMBER: builtins.int
    SPECIAL_BG_COLOR_FIELD_NUMBER: builtins.int
    COVER_URI_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    sub_title1: builtins.str
    """"""
    sub_title2: builtins.str
    """"""
    cover: builtins.str
    """"""
    bg_cover: builtins.str
    """"""
    special_bg_color: builtins.str
    """"""
    cover_uri: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        sub_title1: builtins.str = ...,
        sub_title2: builtins.str = ...,
        cover: builtins.str = ...,
        bg_cover: builtins.str = ...,
        special_bg_color: builtins.str = ...,
        cover_uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_cover", b"bg_cover", "cover", b"cover", "cover_uri", b"cover_uri", "special_bg_color", b"special_bg_color", "sub_title1", b"sub_title1", "sub_title2", b"sub_title2", "title", b"title"]) -> None: ...

global___SearchOgvCard = SearchOgvCard

@typing_extensions.final
class SearchOgvChannelCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    MEDIA_ID_FIELD_NUMBER: builtins.int
    STYLES_FIELD_NUMBER: builtins.int
    AREA_FIELD_NUMBER: builtins.int
    STAFF_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    WATCH_BUTTON_FIELD_NUMBER: builtins.int
    RATING_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    BADGES_V2_FIELD_NUMBER: builtins.int
    STYLES_V2_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    media_id: builtins.int
    """"""
    styles: builtins.str
    """"""
    area: builtins.str
    """"""
    staff: builtins.str
    """"""
    badge: builtins.str
    """"""
    @property
    def watch_button(self) -> global___WatchButton:
        """"""
    rating: builtins.float
    """"""
    desc: builtins.str
    """"""
    @property
    def badges_v2(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReasonStyle]:
        """"""
    styles_v2: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        media_id: builtins.int = ...,
        styles: builtins.str = ...,
        area: builtins.str = ...,
        staff: builtins.str = ...,
        badge: builtins.str = ...,
        watch_button: global___WatchButton | None = ...,
        rating: builtins.float = ...,
        desc: builtins.str = ...,
        badges_v2: collections.abc.Iterable[global___ReasonStyle] | None = ...,
        styles_v2: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["watch_button", b"watch_button"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["area", b"area", "badge", b"badge", "badges_v2", b"badges_v2", "cover", b"cover", "desc", b"desc", "media_id", b"media_id", "rating", b"rating", "staff", b"staff", "styles", b"styles", "styles_v2", b"styles_v2", "title", b"title", "watch_button", b"watch_button"]) -> None: ...

global___SearchOgvChannelCard = SearchOgvChannelCard

@typing_extensions.final
class SearchOgvInlineCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    DANMAKU_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    INLINE_TYPE_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    PLAY_FIELD_NUMBER: builtins.int
    OGV_INLINE_FIELD_NUMBER: builtins.int
    OGV_CLIP_INFO_FIELD_NUMBER: builtins.int
    WATCH_BUTTON_FIELD_NUMBER: builtins.int
    SCORE_FIELD_NUMBER: builtins.int
    OGV_INLINE_EXP_FIELD_NUMBER: builtins.int
    BADGES_V2_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    author: builtins.str
    """"""
    danmaku: builtins.int
    """"""
    desc: builtins.str
    """"""
    face: builtins.str
    """"""
    inline_type: builtins.str
    """"""
    mid: builtins.int
    """"""
    play: builtins.int
    """"""
    @property
    def ogv_inline(self) -> global___SearchInlineData:
        """"""
    @property
    def ogv_clip_info(self) -> global___OgvClipInfo:
        """"""
    @property
    def watch_button(self) -> global___WatchButton:
        """"""
    score: builtins.str
    """"""
    ogv_inline_exp: builtins.int
    """"""
    @property
    def badges_v2(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReasonStyle]:
        """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        author: builtins.str = ...,
        danmaku: builtins.int = ...,
        desc: builtins.str = ...,
        face: builtins.str = ...,
        inline_type: builtins.str = ...,
        mid: builtins.int = ...,
        play: builtins.int = ...,
        ogv_inline: global___SearchInlineData | None = ...,
        ogv_clip_info: global___OgvClipInfo | None = ...,
        watch_button: global___WatchButton | None = ...,
        score: builtins.str = ...,
        ogv_inline_exp: builtins.int = ...,
        badges_v2: collections.abc.Iterable[global___ReasonStyle] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ogv_clip_info", b"ogv_clip_info", "ogv_inline", b"ogv_inline", "watch_button", b"watch_button"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["author", b"author", "badges_v2", b"badges_v2", "cover", b"cover", "danmaku", b"danmaku", "desc", b"desc", "face", b"face", "inline_type", b"inline_type", "mid", b"mid", "ogv_clip_info", b"ogv_clip_info", "ogv_inline", b"ogv_inline", "ogv_inline_exp", b"ogv_inline_exp", "play", b"play", "score", b"score", "title", b"title", "watch_button", b"watch_button"]) -> None: ...

global___SearchOgvInlineCard = SearchOgvInlineCard

@typing_extensions.final
class SearchOgvRecommendCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    SPECIAL_BG_COLOR_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OgvRecommendWord]:
        """"""
    special_bg_color: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        items: collections.abc.Iterable[global___OgvRecommendWord] | None = ...,
        special_bg_color: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "items", b"items", "special_bg_color", b"special_bg_color", "title", b"title"]) -> None: ...

global___SearchOgvRecommendCard = SearchOgvRecommendCard

@typing_extensions.final
class SearchOgvRelationCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    SPECIAL_BG_COLOR_FIELD_NUMBER: builtins.int
    MORE_TEXT_FIELD_NUMBER: builtins.int
    MORE_URL_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    IS_NEW_STYLE_FIELD_NUMBER: builtins.int
    OGV_CARD_UI_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    special_bg_color: builtins.str
    """"""
    more_text: builtins.str
    """"""
    more_url: builtins.str
    """"""
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DetailsRelationItem]:
        """"""
    is_new_style: builtins.int
    """"""
    @property
    def ogv_card_ui(self) -> global___OgvCardUI:
        """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        special_bg_color: builtins.str = ...,
        more_text: builtins.str = ...,
        more_url: builtins.str = ...,
        items: collections.abc.Iterable[global___DetailsRelationItem] | None = ...,
        is_new_style: builtins.int = ...,
        ogv_card_ui: global___OgvCardUI | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ogv_card_ui", b"ogv_card_ui"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "is_new_style", b"is_new_style", "items", b"items", "more_text", b"more_text", "more_url", b"more_url", "ogv_card_ui", b"ogv_card_ui", "special_bg_color", b"special_bg_color", "title", b"title"]) -> None: ...

global___SearchOgvRelationCard = SearchOgvRelationCard

@typing_extensions.final
class SearchOlympicGameCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    SPORTS_MATCH_ITEM_FIELD_NUMBER: builtins.int
    MATCH_TOP_FIELD_NUMBER: builtins.int
    BG_COVER_FIELD_NUMBER: builtins.int
    EXTRA_LINK_FIELD_NUMBER: builtins.int
    INLINE_TYPE_FIELD_NUMBER: builtins.int
    UGC_INLINE_FIELD_NUMBER: builtins.int
    LIVE_ROOM_INLINE_FIELD_NUMBER: builtins.int
    MATCH_BOTTOM_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    @property
    def sports_match_item(self) -> global___SportsMatchItem:
        """"""
    @property
    def match_top(self) -> global___MatchItem:
        """"""
    bg_cover: builtins.str
    """"""
    @property
    def extra_link(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ExtraLink]:
        """"""
    inline_type: builtins.str
    """"""
    @property
    def ugc_inline(self) -> global___SearchInlineData:
        """"""
    @property
    def live_room_inline(self) -> global___SearchInlineData:
        """"""
    @property
    def match_bottom(self) -> global___MatchItem:
        """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        sports_match_item: global___SportsMatchItem | None = ...,
        match_top: global___MatchItem | None = ...,
        bg_cover: builtins.str = ...,
        extra_link: collections.abc.Iterable[global___ExtraLink] | None = ...,
        inline_type: builtins.str = ...,
        ugc_inline: global___SearchInlineData | None = ...,
        live_room_inline: global___SearchInlineData | None = ...,
        match_bottom: global___MatchItem | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["live_room_inline", b"live_room_inline", "match_bottom", b"match_bottom", "match_top", b"match_top", "sports_match_item", b"sports_match_item", "ugc_inline", b"ugc_inline"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_cover", b"bg_cover", "cover", b"cover", "extra_link", b"extra_link", "inline_type", b"inline_type", "live_room_inline", b"live_room_inline", "match_bottom", b"match_bottom", "match_top", b"match_top", "sports_match_item", b"sports_match_item", "title", b"title", "ugc_inline", b"ugc_inline"]) -> None: ...

global___SearchOlympicGameCard = SearchOlympicGameCard

@typing_extensions.final
class SearchOlympicWikiCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    CARD_BUSINESS_BADGE_FIELD_NUMBER: builtins.int
    READ_MORE_FIELD_NUMBER: builtins.int
    INLINE_TYPE_FIELD_NUMBER: builtins.int
    UGC_INLINE_FIELD_NUMBER: builtins.int
    LIVE_ROOM_INLINE_FIELD_NUMBER: builtins.int
    PEDIA_COVER_FIELD_NUMBER: builtins.int
    NAVIGATION_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    @property
    def card_business_badge(self) -> global___CardBusinessBadge:
        """"""
    @property
    def read_more(self) -> global___NavigationButton:
        """"""
    inline_type: builtins.str
    """"""
    @property
    def ugc_inline(self) -> global___SearchInlineData:
        """"""
    @property
    def live_room_inline(self) -> global___SearchInlineData:
        """"""
    @property
    def pedia_cover(self) -> global___PediaCover:
        """"""
    @property
    def navigation(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Navigation]:
        """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        card_business_badge: global___CardBusinessBadge | None = ...,
        read_more: global___NavigationButton | None = ...,
        inline_type: builtins.str = ...,
        ugc_inline: global___SearchInlineData | None = ...,
        live_room_inline: global___SearchInlineData | None = ...,
        pedia_cover: global___PediaCover | None = ...,
        navigation: collections.abc.Iterable[global___Navigation] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["card_business_badge", b"card_business_badge", "live_room_inline", b"live_room_inline", "pedia_cover", b"pedia_cover", "read_more", b"read_more", "ugc_inline", b"ugc_inline"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["card_business_badge", b"card_business_badge", "cover", b"cover", "inline_type", b"inline_type", "live_room_inline", b"live_room_inline", "navigation", b"navigation", "pedia_cover", b"pedia_cover", "read_more", b"read_more", "title", b"title", "ugc_inline", b"ugc_inline"]) -> None: ...

global___SearchOlympicWikiCard = SearchOlympicWikiCard

@typing_extensions.final
class SearchPediaCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    NAVIGATION_FIELD_NUMBER: builtins.int
    READ_MORE_FIELD_NUMBER: builtins.int
    NAVIGATION_MODULE_COUNT_FIELD_NUMBER: builtins.int
    PEDIA_COVER_FIELD_NUMBER: builtins.int
    CARD_BUSINESS_BADGE_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    @property
    def navigation(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Navigation]:
        """"""
    @property
    def read_more(self) -> global___NavigationButton:
        """"""
    navigation_module_count: builtins.int
    """"""
    @property
    def pedia_cover(self) -> global___PediaCover:
        """"""
    @property
    def card_business_badge(self) -> global___CardBusinessBadge:
        """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        navigation: collections.abc.Iterable[global___Navigation] | None = ...,
        read_more: global___NavigationButton | None = ...,
        navigation_module_count: builtins.int = ...,
        pedia_cover: global___PediaCover | None = ...,
        card_business_badge: global___CardBusinessBadge | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["card_business_badge", b"card_business_badge", "pedia_cover", b"pedia_cover", "read_more", b"read_more"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["card_business_badge", b"card_business_badge", "cover", b"cover", "navigation", b"navigation", "navigation_module_count", b"navigation_module_count", "pedia_cover", b"pedia_cover", "read_more", b"read_more", "title", b"title"]) -> None: ...

global___SearchPediaCard = SearchPediaCard

@typing_extensions.final
class SearchPurchaseCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    VENUE_FIELD_NUMBER: builtins.int
    PRICE_FIELD_NUMBER: builtins.int
    PRICE_COMPLETE_FIELD_NUMBER: builtins.int
    PRICE_TYPE_FIELD_NUMBER: builtins.int
    REQUIRED_NUMBER_FIELD_NUMBER: builtins.int
    CITY_FIELD_NUMBER: builtins.int
    SHOW_TIME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    SHOP_NAME_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    badge: builtins.str
    """"""
    venue: builtins.str
    """"""
    price: builtins.int
    """"""
    price_complete: builtins.str
    """"""
    price_type: builtins.int
    """"""
    required_number: builtins.int
    """"""
    city: builtins.str
    """"""
    show_time: builtins.str
    """"""
    id: builtins.int
    """"""
    shop_name: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        badge: builtins.str = ...,
        venue: builtins.str = ...,
        price: builtins.int = ...,
        price_complete: builtins.str = ...,
        price_type: builtins.int = ...,
        required_number: builtins.int = ...,
        city: builtins.str = ...,
        show_time: builtins.str = ...,
        id: builtins.int = ...,
        shop_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge", b"badge", "city", b"city", "cover", b"cover", "id", b"id", "price", b"price", "price_complete", b"price_complete", "price_type", b"price_type", "required_number", b"required_number", "shop_name", b"shop_name", "show_time", b"show_time", "title", b"title", "venue", b"venue"]) -> None: ...

global___SearchPurchaseCard = SearchPurchaseCard

@typing_extensions.final
class SearchRecommendTipCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "title", b"title"]) -> None: ...

global___SearchRecommendTipCard = SearchRecommendTipCard

@typing_extensions.final
class SearchRecommendWordCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    LIST_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RecommendWord]:
        """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        list: collections.abc.Iterable[global___RecommendWord] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "list", b"list", "title", b"title"]) -> None: ...

global___SearchRecommendWordCard = SearchRecommendWordCard

@typing_extensions.final
class SearchSpecialCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    NEW_REC_TAGS_FIELD_NUMBER: builtins.int
    CARD_BUSINESS_BADGE_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    NEW_REC_TAGS_V2_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    @property
    def new_rec_tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReasonStyle]:
        """"""
    @property
    def card_business_badge(self) -> global___CardBusinessBadge:
        """"""
    badge: builtins.str
    """"""
    desc: builtins.str
    """"""
    @property
    def new_rec_tags_v2(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReasonStyle]:
        """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        new_rec_tags: collections.abc.Iterable[global___ReasonStyle] | None = ...,
        card_business_badge: global___CardBusinessBadge | None = ...,
        badge: builtins.str = ...,
        desc: builtins.str = ...,
        new_rec_tags_v2: collections.abc.Iterable[global___ReasonStyle] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["card_business_badge", b"card_business_badge"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge", b"badge", "card_business_badge", b"card_business_badge", "cover", b"cover", "desc", b"desc", "new_rec_tags", b"new_rec_tags", "new_rec_tags_v2", b"new_rec_tags_v2", "title", b"title"]) -> None: ...

global___SearchSpecialCard = SearchSpecialCard

@typing_extensions.final
class SearchSpecialGuideCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    PHONE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    phone: builtins.str
    """"""
    desc: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        phone: builtins.str = ...,
        desc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "desc", b"desc", "phone", b"phone", "title", b"title"]) -> None: ...

global___SearchSpecialGuideCard = SearchSpecialGuideCard

@typing_extensions.final
class SearchSportCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    BG_COVER_FIELD_NUMBER: builtins.int
    MATCH_TOP_FIELD_NUMBER: builtins.int
    MATCH_BOTTOM_FIELD_NUMBER: builtins.int
    EXTRA_LINK_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    bg_cover: builtins.str
    """"""
    @property
    def match_top(self) -> global___MatchItem:
        """"""
    @property
    def match_bottom(self) -> global___MatchItem:
        """"""
    @property
    def extra_link(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ExtraLink]:
        """"""
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MatchInfoObj]:
        """"""
    id: builtins.int
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        bg_cover: builtins.str = ...,
        match_top: global___MatchItem | None = ...,
        match_bottom: global___MatchItem | None = ...,
        extra_link: collections.abc.Iterable[global___ExtraLink] | None = ...,
        items: collections.abc.Iterable[global___MatchInfoObj] | None = ...,
        id: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["match_bottom", b"match_bottom", "match_top", b"match_top"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_cover", b"bg_cover", "cover", b"cover", "extra_link", b"extra_link", "id", b"id", "items", b"items", "match_bottom", b"match_bottom", "match_top", b"match_top", "title", b"title"]) -> None: ...

global___SearchSportCard = SearchSportCard

@typing_extensions.final
class SearchSportInlineCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    BG_COVER_FIELD_NUMBER: builtins.int
    MATCH_TOP_FIELD_NUMBER: builtins.int
    MATCH_BOTTOM_FIELD_NUMBER: builtins.int
    EXTRA_LINK_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    ESPORTS_INLINE_FIELD_NUMBER: builtins.int
    INLINE_TYPE_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    bg_cover: builtins.str
    """"""
    @property
    def match_top(self) -> global___MatchItem:
        """"""
    @property
    def match_bottom(self) -> global___MatchItem:
        """"""
    @property
    def extra_link(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ExtraLink]:
        """"""
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MatchInfoObj]:
        """"""
    id: builtins.int
    """"""
    @property
    def esports_inline(self) -> global___SearchInlineData:
        """"""
    inline_type: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        bg_cover: builtins.str = ...,
        match_top: global___MatchItem | None = ...,
        match_bottom: global___MatchItem | None = ...,
        extra_link: collections.abc.Iterable[global___ExtraLink] | None = ...,
        items: collections.abc.Iterable[global___MatchInfoObj] | None = ...,
        id: builtins.int = ...,
        esports_inline: global___SearchInlineData | None = ...,
        inline_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["esports_inline", b"esports_inline", "match_bottom", b"match_bottom", "match_top", b"match_top"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_cover", b"bg_cover", "cover", b"cover", "esports_inline", b"esports_inline", "extra_link", b"extra_link", "id", b"id", "inline_type", b"inline_type", "items", b"items", "match_bottom", b"match_bottom", "match_top", b"match_top", "title", b"title"]) -> None: ...

global___SearchSportInlineCard = SearchSportInlineCard

@typing_extensions.final
class SearchTipsCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    SUB_TITLE_FIELD_NUMBER: builtins.int
    COVER_NIGHT_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    sub_title: builtins.str
    """"""
    cover_night: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        sub_title: builtins.str = ...,
        cover_night: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "cover_night", b"cover_night", "sub_title", b"sub_title", "title", b"title"]) -> None: ...

global___SearchTipsCard = SearchTipsCard

@typing_extensions.final
class SearchTopGameCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    ARRAY_FIELD_NUMBER: builtins.int
    BACKGROUND_IMAGE_FIELD_NUMBER: builtins.int
    BUTTON_TYPE_FIELD_NUMBER: builtins.int
    GAME_ICON_FIELD_NUMBER: builtins.int
    GAME_BASE_ID_FIELD_NUMBER: builtins.int
    GAME_STATUS_FIELD_NUMBER: builtins.int
    INLINE_TYPE_FIELD_NUMBER: builtins.int
    TOP_GAME_UI_FIELD_NUMBER: builtins.int
    NOTICE_CONTENT_FIELD_NUMBER: builtins.int
    NOTICE_NAME_FIELD_NUMBER: builtins.int
    RATING_FIELD_NUMBER: builtins.int
    SCORE_FIELD_NUMBER: builtins.int
    TAB_INFO_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    UGC_INLINE_FIELD_NUMBER: builtins.int
    VIDEO_COVER_IMAGE_FIELD_NUMBER: builtins.int
    INLINE_LIVE_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    array: builtins.int
    """"""
    background_image: builtins.str
    """"""
    button_type: builtins.int
    """"""
    game_icon: builtins.str
    """"""
    game_base_id: builtins.int
    """"""
    game_status: builtins.int
    """"""
    inline_type: builtins.str
    """"""
    @property
    def top_game_ui(self) -> global___TopGameUI:
        """"""
    notice_content: builtins.str
    """"""
    notice_name: builtins.str
    """"""
    rating: builtins.float
    """"""
    score: builtins.str
    """"""
    @property
    def tab_info(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TabInfo]:
        """"""
    tags: builtins.str
    """"""
    @property
    def ugc_inline(self) -> global___SearchInlineData:
        """"""
    video_cover_image: builtins.str
    """"""
    @property
    def inline_live(self) -> global___SearchInlineData:
        """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        array: builtins.int = ...,
        background_image: builtins.str = ...,
        button_type: builtins.int = ...,
        game_icon: builtins.str = ...,
        game_base_id: builtins.int = ...,
        game_status: builtins.int = ...,
        inline_type: builtins.str = ...,
        top_game_ui: global___TopGameUI | None = ...,
        notice_content: builtins.str = ...,
        notice_name: builtins.str = ...,
        rating: builtins.float = ...,
        score: builtins.str = ...,
        tab_info: collections.abc.Iterable[global___TabInfo] | None = ...,
        tags: builtins.str = ...,
        ugc_inline: global___SearchInlineData | None = ...,
        video_cover_image: builtins.str = ...,
        inline_live: global___SearchInlineData | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["inline_live", b"inline_live", "top_game_ui", b"top_game_ui", "ugc_inline", b"ugc_inline"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["array", b"array", "background_image", b"background_image", "button_type", b"button_type", "cover", b"cover", "game_base_id", b"game_base_id", "game_icon", b"game_icon", "game_status", b"game_status", "inline_live", b"inline_live", "inline_type", b"inline_type", "notice_content", b"notice_content", "notice_name", b"notice_name", "rating", b"rating", "score", b"score", "tab_info", b"tab_info", "tags", b"tags", "title", b"title", "top_game_ui", b"top_game_ui", "ugc_inline", b"ugc_inline", "video_cover_image", b"video_cover_image"]) -> None: ...

global___SearchTopGameCard = SearchTopGameCard

@typing_extensions.final
class SearchUgcInlineCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    DANMAKU_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    INLINE_TYPE_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    PLAY_FIELD_NUMBER: builtins.int
    UGC_INLINE_FIELD_NUMBER: builtins.int
    FULL_TEXT_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    author: builtins.str
    """"""
    danmaku: builtins.int
    """"""
    desc: builtins.str
    """"""
    inline_type: builtins.str
    """"""
    mid: builtins.int
    """"""
    play: builtins.int
    """"""
    @property
    def ugc_inline(self) -> global___SearchInlineData:
        """"""
    @property
    def full_text(self) -> global___FullTextResult:
        """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        author: builtins.str = ...,
        danmaku: builtins.int = ...,
        desc: builtins.str = ...,
        inline_type: builtins.str = ...,
        mid: builtins.int = ...,
        play: builtins.int = ...,
        ugc_inline: global___SearchInlineData | None = ...,
        full_text: global___FullTextResult | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["full_text", b"full_text", "ugc_inline", b"ugc_inline"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["author", b"author", "cover", b"cover", "danmaku", b"danmaku", "desc", b"desc", "full_text", b"full_text", "inline_type", b"inline_type", "mid", b"mid", "play", b"play", "title", b"title", "ugc_inline", b"ugc_inline"]) -> None: ...

global___SearchUgcInlineCard = SearchUgcInlineCard

@typing_extensions.final
class SearchUpperCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    SIGN_FIELD_NUMBER: builtins.int
    FANS_FIELD_NUMBER: builtins.int
    ARCHIVES_FIELD_NUMBER: builtins.int
    LIVE_STATUS_FIELD_NUMBER: builtins.int
    ROOMID_FIELD_NUMBER: builtins.int
    OFFICIAL_VERIFY_FIELD_NUMBER: builtins.int
    FACE_NFT_NEW_FIELD_NUMBER: builtins.int
    NFT_FACE_ICON_FIELD_NUMBER: builtins.int
    AV_ITEMS_FIELD_NUMBER: builtins.int
    IS_UP_FIELD_NUMBER: builtins.int
    ATTENTIONS_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    IS_SENIOR_MEMBER_FIELD_NUMBER: builtins.int
    VIP_FIELD_NUMBER: builtins.int
    RELATION_FIELD_NUMBER: builtins.int
    LIVE_LINK_FIELD_NUMBER: builtins.int
    NOTICE_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    sign: builtins.str
    """"""
    fans: builtins.int
    """"""
    archives: builtins.int
    """"""
    live_status: builtins.int
    """"""
    roomid: builtins.int
    """"""
    @property
    def official_verify(self) -> global___OfficialVerify:
        """"""
    face_nft_new: builtins.int
    """"""
    @property
    def nft_face_icon(self) -> global___NftFaceIcon:
        """"""
    @property
    def av_items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AvItem]:
        """"""
    is_up: builtins.bool
    """"""
    attentions: builtins.int
    """"""
    level: builtins.int
    """"""
    is_senior_member: builtins.int
    """"""
    @property
    def vip(self) -> global___VipInfo:
        """"""
    @property
    def relation(self) -> global___Relation:
        """"""
    live_link: builtins.str
    """"""
    @property
    def notice(self) -> global___Notice:
        """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        sign: builtins.str = ...,
        fans: builtins.int = ...,
        archives: builtins.int = ...,
        live_status: builtins.int = ...,
        roomid: builtins.int = ...,
        official_verify: global___OfficialVerify | None = ...,
        face_nft_new: builtins.int = ...,
        nft_face_icon: global___NftFaceIcon | None = ...,
        av_items: collections.abc.Iterable[global___AvItem] | None = ...,
        is_up: builtins.bool = ...,
        attentions: builtins.int = ...,
        level: builtins.int = ...,
        is_senior_member: builtins.int = ...,
        vip: global___VipInfo | None = ...,
        relation: global___Relation | None = ...,
        live_link: builtins.str = ...,
        notice: global___Notice | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["nft_face_icon", b"nft_face_icon", "notice", b"notice", "official_verify", b"official_verify", "relation", b"relation", "vip", b"vip"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["archives", b"archives", "attentions", b"attentions", "av_items", b"av_items", "cover", b"cover", "face_nft_new", b"face_nft_new", "fans", b"fans", "is_senior_member", b"is_senior_member", "is_up", b"is_up", "level", b"level", "live_link", b"live_link", "live_status", b"live_status", "nft_face_icon", b"nft_face_icon", "notice", b"notice", "official_verify", b"official_verify", "relation", b"relation", "roomid", b"roomid", "sign", b"sign", "title", b"title", "vip", b"vip"]) -> None: ...

global___SearchUpperCard = SearchUpperCard

@typing_extensions.final
class SearchVideoCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    RCMD_REASON_FIELD_NUMBER: builtins.int
    NEW_REC_TAGS_FIELD_NUMBER: builtins.int
    THREE_POINT_FIELD_NUMBER: builtins.int
    SHARE_FIELD_NUMBER: builtins.int
    CARD_BUSINESS_BADGE_FIELD_NUMBER: builtins.int
    PLAY_FIELD_NUMBER: builtins.int
    DANMAKU_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    BADGES_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    SHOW_CARD_DESC1_FIELD_NUMBER: builtins.int
    SHOW_CARD_DESC2_FIELD_NUMBER: builtins.int
    FULL_TEXT_FIELD_NUMBER: builtins.int
    NEW_REC_TAGS_V2_FIELD_NUMBER: builtins.int
    BADGES_V2_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    @property
    def rcmd_reason(self) -> global___RcmdReason:
        """"""
    @property
    def new_rec_tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReasonStyle]:
        """"""
    @property
    def three_point(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ThreePoint]:
        """"""
    @property
    def share(self) -> global___Share:
        """"""
    @property
    def card_business_badge(self) -> global___CardBusinessBadge:
        """"""
    play: builtins.int
    """"""
    danmaku: builtins.int
    """"""
    author: builtins.str
    """"""
    desc: builtins.str
    """"""
    duration: builtins.str
    """"""
    @property
    def badges(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReasonStyle]:
        """"""
    mid: builtins.int
    """"""
    show_card_desc1: builtins.str
    """"""
    show_card_desc2: builtins.str
    """"""
    @property
    def full_text(self) -> global___FullTextResult:
        """"""
    @property
    def new_rec_tags_v2(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReasonStyle]:
        """"""
    @property
    def badges_v2(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReasonStyle]:
        """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        rcmd_reason: global___RcmdReason | None = ...,
        new_rec_tags: collections.abc.Iterable[global___ReasonStyle] | None = ...,
        three_point: collections.abc.Iterable[global___ThreePoint] | None = ...,
        share: global___Share | None = ...,
        card_business_badge: global___CardBusinessBadge | None = ...,
        play: builtins.int = ...,
        danmaku: builtins.int = ...,
        author: builtins.str = ...,
        desc: builtins.str = ...,
        duration: builtins.str = ...,
        badges: collections.abc.Iterable[global___ReasonStyle] | None = ...,
        mid: builtins.int = ...,
        show_card_desc1: builtins.str = ...,
        show_card_desc2: builtins.str = ...,
        full_text: global___FullTextResult | None = ...,
        new_rec_tags_v2: collections.abc.Iterable[global___ReasonStyle] | None = ...,
        badges_v2: collections.abc.Iterable[global___ReasonStyle] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["card_business_badge", b"card_business_badge", "full_text", b"full_text", "rcmd_reason", b"rcmd_reason", "share", b"share"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["author", b"author", "badges", b"badges", "badges_v2", b"badges_v2", "card_business_badge", b"card_business_badge", "cover", b"cover", "danmaku", b"danmaku", "desc", b"desc", "duration", b"duration", "full_text", b"full_text", "mid", b"mid", "new_rec_tags", b"new_rec_tags", "new_rec_tags_v2", b"new_rec_tags_v2", "play", b"play", "rcmd_reason", b"rcmd_reason", "share", b"share", "show_card_desc1", b"show_card_desc1", "show_card_desc2", b"show_card_desc2", "three_point", b"three_point", "title", b"title"]) -> None: ...

global___SearchVideoCard = SearchVideoCard

@typing_extensions.final
class Share(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    VIDEO_FIELD_NUMBER: builtins.int
    type: builtins.str
    """"""
    @property
    def video(self) -> global___Video:
        """"""
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        video: global___Video | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["video", b"video"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type", "video", b"video"]) -> None: ...

global___Share = Share

@typing_extensions.final
class ShareButtonItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    BUTTON_METAS_FIELD_NUMBER: builtins.int
    type: builtins.int
    """"""
    @property
    def button_metas(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ButtonMeta]:
        """"""
    def __init__(
        self,
        *,
        type: builtins.int = ...,
        button_metas: collections.abc.Iterable[global___ButtonMeta] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["button_metas", b"button_metas", "type", b"type"]) -> None: ...

global___ShareButtonItem = ShareButtonItem

@typing_extensions.final
class SharePlane(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    SHARE_SUBTITLE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    SHARE_TO_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    AUTHOR_ID_FIELD_NUMBER: builtins.int
    SHORT_LINK_FIELD_NUMBER: builtins.int
    PLAY_NUMBER_FIELD_NUMBER: builtins.int
    ROOM_ID_FIELD_NUMBER: builtins.int
    EP_ID_FIELD_NUMBER: builtins.int
    AREA_NAME_FIELD_NUMBER: builtins.int
    AUTHOR_FACE_FIELD_NUMBER: builtins.int
    SEASON_ID_FIELD_NUMBER: builtins.int
    SHARE_FROM_FIELD_NUMBER: builtins.int
    SEASON_TITLE_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    share_subtitle: builtins.str
    """"""
    desc: builtins.str
    """"""
    cover: builtins.str
    """"""
    aid: builtins.int
    """"""
    bvid: builtins.str
    """"""
    @property
    def share_to(self) -> global___ShareTo:
        """"""
    author: builtins.str
    """"""
    author_id: builtins.int
    """"""
    short_link: builtins.str
    """"""
    play_number: builtins.str
    """"""
    room_id: builtins.int
    """"""
    ep_id: builtins.int
    """"""
    area_name: builtins.str
    """"""
    author_face: builtins.str
    """"""
    season_id: builtins.int
    """"""
    share_from: builtins.str
    """"""
    season_title: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        share_subtitle: builtins.str = ...,
        desc: builtins.str = ...,
        cover: builtins.str = ...,
        aid: builtins.int = ...,
        bvid: builtins.str = ...,
        share_to: global___ShareTo | None = ...,
        author: builtins.str = ...,
        author_id: builtins.int = ...,
        short_link: builtins.str = ...,
        play_number: builtins.str = ...,
        room_id: builtins.int = ...,
        ep_id: builtins.int = ...,
        area_name: builtins.str = ...,
        author_face: builtins.str = ...,
        season_id: builtins.int = ...,
        share_from: builtins.str = ...,
        season_title: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["share_to", b"share_to"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "area_name", b"area_name", "author", b"author", "author_face", b"author_face", "author_id", b"author_id", "bvid", b"bvid", "cover", b"cover", "desc", b"desc", "ep_id", b"ep_id", "from", b"from", "play_number", b"play_number", "room_id", b"room_id", "season_id", b"season_id", "season_title", b"season_title", "share_from", b"share_from", "share_subtitle", b"share_subtitle", "share_to", b"share_to", "short_link", b"short_link", "title", b"title"]) -> None: ...

global___SharePlane = SharePlane

@typing_extensions.final
class ShareTo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DYNAMIC_FIELD_NUMBER: builtins.int
    IM_FIELD_NUMBER: builtins.int
    COPY_FIELD_NUMBER: builtins.int
    MORE_FIELD_NUMBER: builtins.int
    WECHAT_FIELD_NUMBER: builtins.int
    WEIBO_FIELD_NUMBER: builtins.int
    WECHAT_MONMENT_FIELD_NUMBER: builtins.int
    QQ_FIELD_NUMBER: builtins.int
    QZONE_FIELD_NUMBER: builtins.int
    FACEBOOK_FIELD_NUMBER: builtins.int
    LINE_FIELD_NUMBER: builtins.int
    MESSENGER_FIELD_NUMBER: builtins.int
    WHATS_APP_FIELD_NUMBER: builtins.int
    TWITTER_FIELD_NUMBER: builtins.int
    dynamic: builtins.bool
    """"""
    im: builtins.bool
    """"""
    copy: builtins.bool
    """"""
    more: builtins.bool
    """"""
    wechat: builtins.bool
    """"""
    weibo: builtins.bool
    """"""
    wechat_monment: builtins.bool
    """"""
    qq: builtins.bool
    """"""
    qzone: builtins.bool
    """"""
    facebook: builtins.bool
    """"""
    line: builtins.bool
    """"""
    messenger: builtins.bool
    """"""
    whats_app: builtins.bool
    """"""
    twitter: builtins.bool
    """"""
    def __init__(
        self,
        *,
        dynamic: builtins.bool = ...,
        im: builtins.bool = ...,
        copy: builtins.bool = ...,
        more: builtins.bool = ...,
        wechat: builtins.bool = ...,
        weibo: builtins.bool = ...,
        wechat_monment: builtins.bool = ...,
        qq: builtins.bool = ...,
        qzone: builtins.bool = ...,
        facebook: builtins.bool = ...,
        line: builtins.bool = ...,
        messenger: builtins.bool = ...,
        whats_app: builtins.bool = ...,
        twitter: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["copy", b"copy", "dynamic", b"dynamic", "facebook", b"facebook", "im", b"im", "line", b"line", "messenger", b"messenger", "more", b"more", "qq", b"qq", "qzone", b"qzone", "twitter", b"twitter", "wechat", b"wechat", "wechat_monment", b"wechat_monment", "weibo", b"weibo", "whats_app", b"whats_app"]) -> None: ...

global___ShareTo = ShareTo

@typing_extensions.final
class Space(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHOW_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    TEXT_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    SPACE_URL_FIELD_NUMBER: builtins.int
    show: builtins.int
    """"""
    text_color: builtins.str
    """"""
    text_color_night: builtins.str
    """"""
    text: builtins.str
    """"""
    space_url: builtins.str
    """"""
    def __init__(
        self,
        *,
        show: builtins.int = ...,
        text_color: builtins.str = ...,
        text_color_night: builtins.str = ...,
        text: builtins.str = ...,
        space_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["show", b"show", "space_url", b"space_url", "text", b"text", "text_color", b"text_color", "text_color_night", b"text_color_night"]) -> None: ...

global___Space = Space

@typing_extensions.final
class SportsMatchItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MATCH_ID_FIELD_NUMBER: builtins.int
    SEASON_ID_FIELD_NUMBER: builtins.int
    MATCH_NAME_FIELD_NUMBER: builtins.int
    IMG_FIELD_NUMBER: builtins.int
    BEGIN_TIME_DESC_FIELD_NUMBER: builtins.int
    MATCH_STATUS_DESC_FIELD_NUMBER: builtins.int
    SUB_CONTENT_FIELD_NUMBER: builtins.int
    SUB_EXTRA_ICON_FIELD_NUMBER: builtins.int
    match_id: builtins.int
    """"""
    season_id: builtins.int
    """"""
    match_name: builtins.str
    """"""
    img: builtins.str
    """"""
    begin_time_desc: builtins.str
    """"""
    match_status_desc: builtins.str
    """"""
    sub_content: builtins.str
    """"""
    sub_extra_icon: builtins.str
    """"""
    def __init__(
        self,
        *,
        match_id: builtins.int = ...,
        season_id: builtins.int = ...,
        match_name: builtins.str = ...,
        img: builtins.str = ...,
        begin_time_desc: builtins.str = ...,
        match_status_desc: builtins.str = ...,
        sub_content: builtins.str = ...,
        sub_extra_icon: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["begin_time_desc", b"begin_time_desc", "img", b"img", "match_id", b"match_id", "match_name", b"match_name", "match_status_desc", b"match_status_desc", "season_id", b"season_id", "sub_content", b"sub_content", "sub_extra_icon", b"sub_extra_icon"]) -> None: ...

global___SportsMatchItem = SportsMatchItem

@typing_extensions.final
class Stat(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAY_FIELD_NUMBER: builtins.int
    LIKE_FIELD_NUMBER: builtins.int
    REPLY_FIELD_NUMBER: builtins.int
    play: builtins.int
    """"""
    like: builtins.int
    """"""
    reply: builtins.int
    """"""
    def __init__(
        self,
        *,
        play: builtins.int = ...,
        like: builtins.int = ...,
        reply: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["like", b"like", "play", b"play", "reply", b"reply"]) -> None: ...

global___Stat = Stat

@typing_extensions.final
class TabInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TAB_NAME_FIELD_NUMBER: builtins.int
    TAB_URL_FIELD_NUMBER: builtins.int
    SORT_FIELD_NUMBER: builtins.int
    tab_name: builtins.str
    """"""
    tab_url: builtins.str
    """"""
    sort: builtins.int
    """"""
    def __init__(
        self,
        *,
        tab_name: builtins.str = ...,
        tab_url: builtins.str = ...,
        sort: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sort", b"sort", "tab_name", b"tab_name", "tab_url", b"tab_url"]) -> None: ...

global___TabInfo = TabInfo

@typing_extensions.final
class TextButton(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    text: builtins.str
    """"""
    uri: builtins.str
    """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["text", b"text", "uri", b"uri"]) -> None: ...

global___TextButton = TextButton

@typing_extensions.final
class TextLabel(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    text: builtins.str
    """"""
    uri: builtins.str
    """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["text", b"text", "uri", b"uri"]) -> None: ...

global___TextLabel = TextLabel

@typing_extensions.final
class Texts(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BOOKING_TEXT_FIELD_NUMBER: builtins.int
    UNBOOKING_TEXT_FIELD_NUMBER: builtins.int
    booking_text: builtins.str
    """"""
    unbooking_text: builtins.str
    """"""
    def __init__(
        self,
        *,
        booking_text: builtins.str = ...,
        unbooking_text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["booking_text", b"booking_text", "unbooking_text", b"unbooking_text"]) -> None: ...

global___Texts = Texts

@typing_extensions.final
class ThreePoint(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    type: builtins.str
    """"""
    icon: builtins.str
    """"""
    title: builtins.str
    """"""
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        icon: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "title", b"title", "type", b"type"]) -> None: ...

global___ThreePoint = ThreePoint

@typing_extensions.final
class ThreePoint2(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISLIKE_REASONS_FIELD_NUMBER: builtins.int
    FEEDBACKS_FIELD_NUMBER: builtins.int
    WATCH_LATER_FIELD_NUMBER: builtins.int
    @property
    def dislike_reasons(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DislikeReason]:
        """"""
    @property
    def feedbacks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DislikeReason]:
        """"""
    watch_later: builtins.int
    """"""
    def __init__(
        self,
        *,
        dislike_reasons: collections.abc.Iterable[global___DislikeReason] | None = ...,
        feedbacks: collections.abc.Iterable[global___DislikeReason] | None = ...,
        watch_later: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dislike_reasons", b"dislike_reasons", "feedbacks", b"feedbacks", "watch_later", b"watch_later"]) -> None: ...

global___ThreePoint2 = ThreePoint2

@typing_extensions.final
class ThreePointV2(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    REASONS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    subtitle: builtins.str
    """"""
    @property
    def reasons(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DislikeReason]:
        """"""
    type: builtins.str
    """"""
    id: builtins.int
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        subtitle: builtins.str = ...,
        reasons: collections.abc.Iterable[global___DislikeReason] | None = ...,
        type: builtins.str = ...,
        id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "reasons", b"reasons", "subtitle", b"subtitle", "title", b"title", "type", b"type"]) -> None: ...

global___ThreePointV2 = ThreePointV2

@typing_extensions.final
class ThreePointV3(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    SELECTED_TITLE_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    REASONS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    SELECTED_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    SELECTED_ICON_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    DEFAULT_ID_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    selected_title: builtins.str
    """"""
    subtitle: builtins.str
    """"""
    @property
    def reasons(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DislikeReason]:
        """"""
    type: builtins.str
    """"""
    id: builtins.int
    """"""
    selected: builtins.int
    """"""
    icon: builtins.str
    """"""
    selected_icon: builtins.str
    """"""
    url: builtins.str
    """"""
    default_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        selected_title: builtins.str = ...,
        subtitle: builtins.str = ...,
        reasons: collections.abc.Iterable[global___DislikeReason] | None = ...,
        type: builtins.str = ...,
        id: builtins.int = ...,
        selected: builtins.int = ...,
        icon: builtins.str = ...,
        selected_icon: builtins.str = ...,
        url: builtins.str = ...,
        default_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_id", b"default_id", "icon", b"icon", "id", b"id", "reasons", b"reasons", "selected", b"selected", "selected_icon", b"selected_icon", "selected_title", b"selected_title", "subtitle", b"subtitle", "title", b"title", "type", b"type", "url", b"url"]) -> None: ...

global___ThreePointV3 = ThreePointV3

@typing_extensions.final
class ThreePointV4(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHARE_PLANE_FIELD_NUMBER: builtins.int
    WATCH_LATER_FIELD_NUMBER: builtins.int
    @property
    def share_plane(self) -> global___SharePlane:
        """"""
    @property
    def watch_later(self) -> global___WatchLater:
        """"""
    def __init__(
        self,
        *,
        share_plane: global___SharePlane | None = ...,
        watch_later: global___WatchLater | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["share_plane", b"share_plane", "watch_later", b"watch_later"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["share_plane", b"share_plane", "watch_later", b"watch_later"]) -> None: ...

global___ThreePointV4 = ThreePointV4

@typing_extensions.final
class TopGameUI(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKGROUND_IMAGE_FIELD_NUMBER: builtins.int
    COVER_DEFAULT_COLOR_FIELD_NUMBER: builtins.int
    GAUSSIAN_BLUR_VALUE_FIELD_NUMBER: builtins.int
    MASK_COLOR_VALUE_FIELD_NUMBER: builtins.int
    MASK_OPACITY_FIELD_NUMBER: builtins.int
    MODULE_COLOR_FIELD_NUMBER: builtins.int
    background_image: builtins.str
    """"""
    cover_default_color: builtins.str
    """"""
    gaussian_blur_value: builtins.str
    """"""
    mask_color_value: builtins.str
    """"""
    mask_opacity: builtins.str
    """"""
    module_color: builtins.str
    """"""
    def __init__(
        self,
        *,
        background_image: builtins.str = ...,
        cover_default_color: builtins.str = ...,
        gaussian_blur_value: builtins.str = ...,
        mask_color_value: builtins.str = ...,
        mask_opacity: builtins.str = ...,
        module_color: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["background_image", b"background_image", "cover_default_color", b"cover_default_color", "gaussian_blur_value", b"gaussian_blur_value", "mask_color_value", b"mask_color_value", "mask_opacity", b"mask_opacity", "module_color", b"module_color"]) -> None: ...

global___TopGameUI = TopGameUI

@typing_extensions.final
class TrafficConfig(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    DEFAULT_OPTION_ID_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    @property
    def options(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TrafficConfigOption]:
        """"""
    default_option_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        options: collections.abc.Iterable[global___TrafficConfigOption] | None = ...,
        default_option_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_option_id", b"default_option_id", "options", b"options", "title", b"title"]) -> None: ...

global___TrafficConfig = TrafficConfig

@typing_extensions.final
class TrafficConfigOption(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    text: builtins.str
    """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "text", b"text"]) -> None: ...

global___TrafficConfigOption = TrafficConfigOption

@typing_extensions.final
class UpArgs(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UP_ID_FIELD_NUMBER: builtins.int
    UP_NAME_FIELD_NUMBER: builtins.int
    UP_FACE_FIELD_NUMBER: builtins.int
    SELECTED_FIELD_NUMBER: builtins.int
    up_id: builtins.int
    """"""
    up_name: builtins.str
    """"""
    up_face: builtins.str
    """"""
    selected: builtins.int
    """"""
    def __init__(
        self,
        *,
        up_id: builtins.int = ...,
        up_name: builtins.str = ...,
        up_face: builtins.str = ...,
        selected: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["selected", b"selected", "up_face", b"up_face", "up_id", b"up_id", "up_name", b"up_name"]) -> None: ...

global___UpArgs = UpArgs

@typing_extensions.final
class Upper(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    PTIME_TEXT_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    ptime_text: builtins.str
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        ptime_text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "mid", b"mid", "ptime_text", b"ptime_text", "title", b"title"]) -> None: ...

global___Upper = Upper

@typing_extensions.final
class Video(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BVID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    SHARE_SUBTITLE_FIELD_NUMBER: builtins.int
    IS_HOT_LABEL_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    PAGE_COUNT_FIELD_NUMBER: builtins.int
    SHORT_LINK_FIELD_NUMBER: builtins.int
    bvid: builtins.str
    """"""
    cid: builtins.int
    """"""
    share_subtitle: builtins.str
    """"""
    is_hot_label: builtins.bool
    """"""
    page: builtins.int
    """"""
    page_count: builtins.int
    """"""
    short_link: builtins.str
    """"""
    def __init__(
        self,
        *,
        bvid: builtins.str = ...,
        cid: builtins.int = ...,
        share_subtitle: builtins.str = ...,
        is_hot_label: builtins.bool = ...,
        page: builtins.int = ...,
        page_count: builtins.int = ...,
        short_link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bvid", b"bvid", "cid", b"cid", "is_hot_label", b"is_hot_label", "page", b"page", "page_count", b"page_count", "share_subtitle", b"share_subtitle", "short_link", b"short_link"]) -> None: ...

global___Video = Video

@typing_extensions.final
class VipInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    DUE_DATE_FIELD_NUMBER: builtins.int
    VIP_PAY_TYPE_FIELD_NUMBER: builtins.int
    THEME_TYPE_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    AVATAR_SUBSCRIPT_FIELD_NUMBER: builtins.int
    NICKNAME_COLOR_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    AVATAR_SUBSCRIPT_URL_FIELD_NUMBER: builtins.int
    TV_VIP_STATUS_FIELD_NUMBER: builtins.int
    TV_VIP_PAY_TYPE_FIELD_NUMBER: builtins.int
    type: builtins.int
    """"""
    status: builtins.int
    """"""
    due_date: builtins.int
    """"""
    vip_pay_type: builtins.int
    """"""
    theme_type: builtins.int
    """"""
    @property
    def label(self) -> global___VipLabel:
        """"""
    avatar_subscript: builtins.int
    """"""
    nickname_color: builtins.str
    """"""
    role: builtins.int
    """"""
    avatar_subscript_url: builtins.str
    """"""
    tv_vip_status: builtins.int
    """"""
    tv_vip_pay_type: builtins.int
    """"""
    def __init__(
        self,
        *,
        type: builtins.int = ...,
        status: builtins.int = ...,
        due_date: builtins.int = ...,
        vip_pay_type: builtins.int = ...,
        theme_type: builtins.int = ...,
        label: global___VipLabel | None = ...,
        avatar_subscript: builtins.int = ...,
        nickname_color: builtins.str = ...,
        role: builtins.int = ...,
        avatar_subscript_url: builtins.str = ...,
        tv_vip_status: builtins.int = ...,
        tv_vip_pay_type: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["label", b"label"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["avatar_subscript", b"avatar_subscript", "avatar_subscript_url", b"avatar_subscript_url", "due_date", b"due_date", "label", b"label", "nickname_color", b"nickname_color", "role", b"role", "status", b"status", "theme_type", b"theme_type", "tv_vip_pay_type", b"tv_vip_pay_type", "tv_vip_status", b"tv_vip_status", "type", b"type", "vip_pay_type", b"vip_pay_type"]) -> None: ...

global___VipInfo = VipInfo

@typing_extensions.final
class VipLabel(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    LABEL_THEME_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    BG_STYLE_FIELD_NUMBER: builtins.int
    BG_COLOR_FIELD_NUMBER: builtins.int
    BORDER_COLOR_FIELD_NUMBER: builtins.int
    USE_IMG_LABEL_FIELD_NUMBER: builtins.int
    IMG_LABEL_URI_HANS_FIELD_NUMBER: builtins.int
    IMG_LABEL_URI_HANT_FIELD_NUMBER: builtins.int
    IMG_LABEL_URI_HANS_STATIC_FIELD_NUMBER: builtins.int
    IMG_LABEL_URI_HANT_STATIC_FIELD_NUMBER: builtins.int
    path: builtins.str
    """"""
    text: builtins.str
    """"""
    label_theme: builtins.str
    """"""
    text_color: builtins.str
    """"""
    bg_style: builtins.int
    """"""
    bg_color: builtins.str
    """"""
    border_color: builtins.str
    """"""
    use_img_label: builtins.bool
    """"""
    img_label_uri_hans: builtins.str
    """"""
    img_label_uri_hant: builtins.str
    """"""
    img_label_uri_hans_static: builtins.str
    """"""
    img_label_uri_hant_static: builtins.str
    """"""
    def __init__(
        self,
        *,
        path: builtins.str = ...,
        text: builtins.str = ...,
        label_theme: builtins.str = ...,
        text_color: builtins.str = ...,
        bg_style: builtins.int = ...,
        bg_color: builtins.str = ...,
        border_color: builtins.str = ...,
        use_img_label: builtins.bool = ...,
        img_label_uri_hans: builtins.str = ...,
        img_label_uri_hant: builtins.str = ...,
        img_label_uri_hans_static: builtins.str = ...,
        img_label_uri_hant_static: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_color", b"bg_color", "bg_style", b"bg_style", "border_color", b"border_color", "img_label_uri_hans", b"img_label_uri_hans", "img_label_uri_hans_static", b"img_label_uri_hans_static", "img_label_uri_hant", b"img_label_uri_hant", "img_label_uri_hant_static", b"img_label_uri_hant_static", "label_theme", b"label_theme", "path", b"path", "text", b"text", "text_color", b"text_color", "use_img_label", b"use_img_label"]) -> None: ...

global___VipLabel = VipLabel

@typing_extensions.final
class WatchButton(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    link: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["link", b"link", "title", b"title"]) -> None: ...

global___WatchButton = WatchButton

@typing_extensions.final
class WatchedShow(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SWITCH_FIELD_NUMBER: builtins.int
    NUM_FIELD_NUMBER: builtins.int
    TEXT_SMALL_FIELD_NUMBER: builtins.int
    TEXT_LARGE_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    ICON_LOCATION_FIELD_NUMBER: builtins.int
    ICON_WEB_FIELD_NUMBER: builtins.int
    switch: builtins.bool
    """"""
    num: builtins.int
    """"""
    text_small: builtins.str
    """"""
    text_large: builtins.str
    """"""
    icon: builtins.str
    """"""
    icon_location: builtins.str
    """"""
    icon_web: builtins.str
    """"""
    def __init__(
        self,
        *,
        switch: builtins.bool = ...,
        num: builtins.int = ...,
        text_small: builtins.str = ...,
        text_large: builtins.str = ...,
        icon: builtins.str = ...,
        icon_location: builtins.str = ...,
        icon_web: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "icon_location", b"icon_location", "icon_web", b"icon_web", "num", b"num", "switch", b"switch", "text_large", b"text_large", "text_small", b"text_small"]) -> None: ...

global___WatchedShow = WatchedShow

@typing_extensions.final
class WatchLater(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""
    bvid: builtins.str
    """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        bvid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "bvid", b"bvid"]) -> None: ...

global___WatchLater = WatchLater
